@@ -2,7 +2,7 @@ import functools
 
 from fonticon_mdi7 import MDI7
 from PySide6.QtCore import QObject, QUrl, Slot
-from PySide6.QtQml import QmlElement, QmlSingleton
+from PySide6.QtQml import QmlElement
 
 from __feature__ import snake_case, true_property  # isort:skip # noqa: F401
 
@@ -12,7 +12,6 @@ QML_IMPORT_MINOR_VERSION = 0
 
 
 @QmlElement
-@QmlSingleton
 class IconicFontLoader(QObject):
     @Slot(str, result=str)
     def font_path(self, font_family: str) -> str:
