@@ -1,16 +1,16 @@
-from dataclasses import dataclass, field
 from decimal import Decimal
-from typing import Optional, Union
 
 from xsdata.models.datatype import XmlTime
+from xsdata_pydantic.fields import field
+
+from libresvip.model.base import BaseModel
 
 
-@dataclass
-class CeVIOAuthor:
+class CeVIOAuthor(BaseModel):
     class Meta:
         name = "Author"
 
-    version: Optional[str] = field(
+    version: str | None = field(
         default="3.2.21.2",
         metadata={
             "name": "Version",
@@ -19,19 +19,18 @@ class CeVIOAuthor:
     )
 
 
-@dataclass
-class CeVIONoData:
+class CeVIONoData(BaseModel):
     class Meta:
         name = "NoData"
 
-    index: Optional[int] = field(
+    index: int | None = field(
         default=None,
         metadata={
             "name": "Index",
             "type": "Attribute",
         },
     )
-    repeat: Optional[int] = field(
+    repeat: int | None = field(
         default=None,
         metadata={
             "name": "Repeat",
@@ -40,20 +39,18 @@ class CeVIONoData:
     )
 
 
-@dataclass
 class CeVIOData(CeVIONoData):
     class Meta:
         name = "Data"
 
-    value: Optional[Union[float, int, Decimal]] = field(default=None)
+    value: float | int | Decimal | None = field(default=None)
 
 
-@dataclass
-class CeVIODictExtension:
+class CeVIODictExtension(BaseModel):
     class Meta:
         name = "Extension"
 
-    version: Optional[str] = field(
+    version: str | None = field(
         default="1.0.0",
         metadata={
             "name": "Version",
@@ -61,7 +58,7 @@ class CeVIODictExtension:
         },
     )
 
-    language: Optional[str] = field(
+    language: str | None = field(
         default="English",
         metadata={
             "name": "Language",
@@ -70,19 +67,18 @@ class CeVIODictExtension:
     )
 
 
-@dataclass
-class CeVIODictionary:
+class CeVIODictionary(BaseModel):
     class Meta:
         name = "Dictionary"
 
-    version: Optional[str] = field(
+    version: str | None = field(
         default="1.0.0",
         metadata={
             "name": "Version",
             "type": "Attribute",
         },
     )
-    extension: Optional[CeVIODictExtension] = field(
+    extension: CeVIODictExtension | None = field(
         default=None,
         metadata={
             "name": "Extension",
@@ -91,19 +87,18 @@ class CeVIODictionary:
     )
 
 
-@dataclass
-class CeVIODynamics:
+class CeVIODynamics(BaseModel):
     class Meta:
         name = "Dynamics"
 
-    clock: Optional[int] = field(
+    clock: int | None = field(
         default=None,
         metadata={
             "name": "Clock",
             "type": "Attribute",
         },
     )
-    value: Optional[int] = field(
+    value: int | None = field(
         default=None,
         metadata={
             "name": "Value",
@@ -112,12 +107,11 @@ class CeVIODynamics:
     )
 
 
-@dataclass
-class CeVIOTalkExtension:
+class CeVIOTalkExtension(BaseModel):
     class Meta:
         name = "Extension"
 
-    vertical_ratio: Optional[str] = field(
+    vertical_ratio: str | None = field(
         default=None,
         metadata={
             "name": "VerticalRatio",
@@ -126,19 +120,18 @@ class CeVIOTalkExtension:
     )
 
 
-@dataclass
-class CeVIOGroup:
+class CeVIOGroup(BaseModel):
     class Meta:
         name = "Group"
 
-    version: Optional[str] = field(
+    version: str | None = field(
         default="1.0",
         metadata={
             "name": "Version",
             "type": "Attribute",
         },
     )
-    group_id: Optional[str] = field(
+    group_id: str | None = field(
         default=None,
         metadata={
             "name": "Id",
@@ -152,63 +145,63 @@ class CeVIOGroup:
             "type": "Attribute",
         },
     )
-    name: Optional[str] = field(
+    name: str | None = field(
         default=None,
         metadata={
             "name": "Name",
             "type": "Attribute",
         },
     )
-    color: Optional[str] = field(
+    color: str | None = field(
         default=None,
         metadata={
             "name": "Color",
             "type": "Attribute",
         },
     )
-    volume: Optional[float] = field(
+    volume: float | None = field(
         default=None,
         metadata={
             "name": "Volume",
             "type": "Attribute",
         },
     )
-    pan: Optional[float] = field(
+    pan: float | None = field(
         default=None,
         metadata={
             "name": "Pan",
             "type": "Attribute",
         },
     )
-    is_solo: Optional[bool] = field(
+    is_solo: bool | None = field(
         default=False,
         metadata={
             "name": "IsSolo",
             "type": "Attribute",
         },
     )
-    is_muted: Optional[bool] = field(
+    is_muted: bool | None = field(
         default=False,
         metadata={
             "name": "IsMuted",
             "type": "Attribute",
         },
     )
-    cast_id: Optional[str] = field(
+    cast_id: str | None = field(
         default=None,
         metadata={
             "name": "CastId",
             "type": "Attribute",
         },
     )
-    language: Optional[str] = field(
+    language: str | None = field(
         default="Japanese",
         metadata={
             "name": "Language",
             "type": "Attribute",
         },
     )
-    snapshot: Optional[str] = field(
+    snapshot: str | None = field(
         default=None,
         metadata={
             "name": "SnapShot",
@@ -217,26 +210,25 @@ class CeVIOGroup:
     )
 
 
-@dataclass
-class CeVIOKey:
+class CeVIOKey(BaseModel):
     class Meta:
         name = "Key"
 
-    clock: Optional[int] = field(
+    clock: int | None = field(
         default=None,
         metadata={
             "name": "Clock",
             "type": "Attribute",
         },
     )
-    fifths: Optional[int] = field(
+    fifths: int | None = field(
         default=None,
         metadata={
             "name": "Fifths",
             "type": "Attribute",
         },
     )
-    mode: Optional[int] = field(
+    mode: int | None = field(
         default=None,
         metadata={
             "name": "Mode",
@@ -245,96 +237,95 @@ class CeVIOKey:
     )
 
 
-@dataclass
-class CeVIONote:
+class CeVIONote(BaseModel):
     class Meta:
         name = "Note"
 
-    clock: Optional[int] = field(
+    clock: int | None = field(
         default=None,
         metadata={
             "name": "Clock",
             "type": "Attribute",
         },
     )
-    pitch_step: Optional[int] = field(
+    pitch_step: int | None = field(
         default=None,
         metadata={
             "name": "PitchStep",
             "type": "Attribute",
         },
     )
-    pitch_octave: Optional[int] = field(
+    pitch_octave: int | None = field(
         default=None,
         metadata={
             "name": "PitchOctave",
             "type": "Attribute",
         },
     )
-    duration: Optional[int] = field(
+    duration: int | None = field(
         default=None,
         metadata={
             "name": "Duration",
             "type": "Attribute",
         },
     )
-    lyric: Optional[str] = field(
+    lyric: str | None = field(
         default=None,
         metadata={
             "name": "Lyric",
             "type": "Attribute",
         },
     )
-    phonetic: Optional[str] = field(
+    phonetic: str | None = field(
         default=None,
         metadata={
             "name": "Phonetic",
             "type": "Attribute",
         },
     )
-    do_re_mi: Optional[bool] = field(
+    do_re_mi: bool | None = field(
         default=None,
         metadata={
             "name": "DoReMi",
             "type": "Attribute",
         },
     )
-    staccato: Optional[bool] = field(
+    staccato: bool | None = field(
         default=None,
         metadata={
             "name": "Staccato",
             "type": "Attribute",
         },
     )
-    slur_start: Optional[bool] = field(
+    slur_start: bool | None = field(
         default=None,
         metadata={
             "name": "SlurStart",
             "type": "Attribute",
         },
     )
-    slur_stop: Optional[bool] = field(
+    slur_stop: bool | None = field(
         default=None,
         metadata={
             "name": "SlurStop",
             "type": "Attribute",
         },
     )
-    syllabic: Optional[int] = field(
+    syllabic: int | None = field(
         default=None,
         metadata={
             "name": "Syllabic",
             "type": "Attribute",
         },
     )
-    accent: Optional[bool] = field(
+    accent: bool | None = field(
         default=None,
         metadata={
             "name": "Accent",
             "type": "Attribute",
         },
     )
-    breath: Optional[bool] = field(
+    breath: bool | None = field(
         default=None,
         metadata={
             "name": "Breath",
@@ -343,19 +334,18 @@ class CeVIONote:
     )
 
 
-@dataclass
-class CeVIOReferenceState:
+class CeVIOReferenceState(BaseModel):
     class Meta:
         name = "ReferenceState"
 
-    current: Optional[str] = field(
+    current: str | None = field(
         default=None,
         metadata={
             "name": "Current",
             "type": "Attribute",
         },
     )
-    previous: Optional[str] = field(
+    previous: str | None = field(
         default=None,
         metadata={
             "name": "Previous",
@@ -364,19 +354,18 @@ class CeVIOReferenceState:
     )
 
 
-@dataclass
-class CeVIOSound:
+class CeVIOSound(BaseModel):
     class Meta:
         name = "Sound"
 
-    clock: Optional[int] = field(
+    clock: int | None = field(
         default=None,
         metadata={
             "name": "Clock",
             "type": "Attribute",
         },
     )
-    tempo: Optional[float] = field(
+    tempo: float | None = field(
         default=None,
         metadata={
             "name": "Tempo",
@@ -385,26 +374,25 @@ class CeVIOSound:
     )
 
 
-@dataclass
-class CeVIOSoundSetting:
+class CeVIOSoundSetting(BaseModel):
     class Meta:
         name = "SoundSetting"
 
-    rhythm: Optional[str] = field(
+    rhythm: str | None = field(
         default="4/4",
         metadata={
             "name": "Rhythm",
             "type": "Attribute",
         },
     )
-    tempo: Optional[float] = field(
+    tempo: float | None = field(
         default=120.0,
         metadata={
             "name": "Tempo",
             "type": "Attribute",
         },
     )
-    master_volume: Optional[float] = field(
+    master_volume: float | None = field(
         default=None,
         metadata={
             "name": "MasterVolume",
@@ -413,26 +401,25 @@ class CeVIOSoundSetting:
     )
 
 
-@dataclass
-class CeVIOSoundSource:
+class CeVIOSoundSource(BaseModel):
     class Meta:
         name = "SoundSource"
 
-    version: Optional[str] = field(
+    version: str | None = field(
         default="1.0.0",
         metadata={
             "name": "Version",
             "type": "Attribute",
         },
     )
-    sound_source_id: Optional[str] = field(
+    sound_source_id: str | None = field(
         default=None,
         metadata={
             "name": "Id",
             "type": "Attribute",
         },
     )
-    name: Optional[str] = field(
+    name: str | None = field(
         default=None,
         metadata={
             "name": "Name",
@@ -441,26 +428,24 @@ class CeVIOSoundSource:
     )
 
 
-@dataclass
-class CeVIOTime:
+class CeVIOTime(BaseModel):
     class Meta:
         name = "Time"
 
-    clock: Optional[int] = field(
-        default=None,
+    clock: int = field(
         metadata={
             "name": "Clock",
             "type": "Attribute",
         },
     )
-    beats: Optional[int] = field(
+    beats: int | None = field(
         default=None,
         metadata={
             "name": "Beats",
             "type": "Attribute",
         },
     )
-    beat_type: Optional[int] = field(
+    beat_type: int | None = field(
         default=None,
         metadata={
             "name": "BeatType",
@@ -469,19 +454,18 @@ class CeVIOTime:
     )
 
 
-@dataclass
-class CeVIOViewScale:
+class CeVIOViewScale(BaseModel):
     class Meta:
         name = "ViewScale"
 
-    horizontal: Optional[Union[int, float]] = field(
+    horizontal: int | float | None = field(
         default=None,
         metadata={
             "name": "Horizontal",
             "type": "Attribute",
         },
     )
-    vertical: Optional[Union[int, Decimal]] = field(
+    vertical: int | Decimal | None = field(
         default=None,
         metadata={
             "name": "Vertical",
@@ -490,8 +474,7 @@ class CeVIOViewScale:
     )
 
 
-@dataclass
-class CeVIOBeat:
+class CeVIOBeat(BaseModel):
     class Meta:
         name = "Beat"
 
@@ -504,12 +487,11 @@ class CeVIOBeat:
     )
 
 
-@dataclass
-class CeVIOGroups:
+class CeVIOGroups(BaseModel):
     class Meta:
         name = "Groups"
 
-    active_group: Optional[str] = field(
+    active_group: str | None = field(
         default=None,
         metadata={
             "name": "ActiveGroup",
@@ -525,68 +507,67 @@ class CeVIOGroups:
     )
 
 
-@dataclass
-class CeVIOScore:
+class CeVIOScore(BaseModel):
     class Meta:
         name = "Score"
 
-    alpha: Optional[float] = field(
+    alpha: float | None = field(
         default=None,
         metadata={
             "name": "Alpha",
             "type": "Attribute",
         },
     )
-    tune: Optional[float] = field(
+    tune: float | None = field(
         default=None,
         metadata={
             "name": "Tune",
             "type": "Attribute",
         },
     )
-    pitch_shift: Optional[float] = field(
+    pitch_shift: float | None = field(
         default=None,
         metadata={
             "name": "PitchShift",
             "type": "Attribute",
         },
     )
-    pitch_tune: Optional[float] = field(
+    pitch_tune: float | None = field(
         default=None,
         metadata={
             "name": "PitchTune",
             "type": "Attribute",
         },
     )
-    husky: Optional[float] = field(
+    husky: float | None = field(
         default=None,
         metadata={
             "name": "Husky",
             "type": "Attribute",
         },
     )
-    vib_amp: Optional[float] = field(
+    vib_amp: float | None = field(
         default=None,
         metadata={
             "name": "VibAmp",
             "type": "Attribute",
         },
     )
-    vib_frq: Optional[float] = field(
+    vib_frq: float | None = field(
         default=None,
         metadata={
             "name": "VibFrq",
             "type": "Attribute",
         },
     )
-    emotion0: Optional[Union[float, int]] = field(
+    emotion0: float | int | None = field(
         default=None,
         metadata={
             "name": "Emotion0",
             "type": "Attribute",
         },
     )
-    emotion1: Optional[Union[float, int]] = field(
+    emotion1: float | int | None = field(
         default=None,
         metadata={
             "name": "Emotion1",
@@ -618,47 +599,46 @@ class CeVIOScore:
     )
 
 
-@dataclass
-class CeVIOSongEditor:
+class CeVIOSongEditor(BaseModel):
     class Meta:
         name = "SongEditor"
 
-    partition: Optional[int] = field(
+    partition: int | None = field(
         default=None,
         metadata={
             "name": "Partition",
             "type": "Attribute",
         },
     )
-    quantize: Optional[int] = field(
+    quantize: int | None = field(
         default=None,
         metadata={
             "name": "Quantize",
             "type": "Attribute",
         },
     )
-    mode: Optional[int] = field(
+    mode: int | None = field(
         default=None,
         metadata={
             "name": "Mode",
             "type": "Attribute",
         },
     )
-    editing_tool: Optional[int] = field(
+    editing_tool: int | None = field(
         default=None,
         metadata={
             "name": "EditingTool",
             "type": "Attribute",
         },
     )
-    view_scale: Optional[CeVIOViewScale] = field(
+    view_scale: CeVIOViewScale | None = field(
         default=None,
         metadata={
             "name": "ViewScale",
             "type": "Element",
         },
     )
-    reference_state: Optional[CeVIOReferenceState] = field(
+    reference_state: CeVIOReferenceState | None = field(
         default=None,
         metadata={
             "name": "ReferenceState",
@@ -667,8 +647,7 @@ class CeVIOSongEditor:
     )
 
 
-@dataclass
-class CeVIOSoundSources:
+class CeVIOSoundSources(BaseModel):
     class Meta:
         name = "SoundSources"
 
@@ -681,26 +660,25 @@ class CeVIOSoundSources:
     )
 
 
-@dataclass
-class CeVIOTts:
+class CeVIOTts(BaseModel):
     class Meta:
         name = "TTS"
 
-    version: Optional[str] = field(
+    version: str | None = field(
         default="3.1.0",
         metadata={
             "name": "Version",
             "type": "Attribute",
         },
     )
-    dictionary: Optional[CeVIODictionary] = field(
+    dictionary: CeVIODictionary | None = field(
         default_factory=CeVIODictionary,
         metadata={
             "name": "Dictionary",
             "type": "Element",
         },
     )
-    sound_sources: Optional[CeVIOSoundSources] = field(
+    sound_sources: CeVIOSoundSources = field(
         default_factory=CeVIOSoundSources,
         metadata={
             "name": "SoundSources",
@@ -709,19 +687,18 @@ class CeVIOTts:
     )
 
 
-@dataclass
-class CeVIOTalkEditor:
+class CeVIOTalkEditor(BaseModel):
     class Meta:
         name = "TalkEditor"
 
-    partition: Optional[int] = field(
+    partition: int | None = field(
         default=None,
         metadata={
             "name": "Partition",
             "type": "Attribute",
         },
     )
-    extension: Optional[CeVIOTalkExtension] = field(
+    extension: CeVIOTalkExtension | None = field(
         default=None,
         metadata={
             "name": "Extension",
@@ -730,8 +707,7 @@ class CeVIOTalkEditor:
     )
 
 
-@dataclass
-class CeVIOTempo:
+class CeVIOTempo(BaseModel):
     class Meta:
         name = "Tempo"
 
@@ -744,33 +720,39 @@ class CeVIOTempo:
     )
 
 
-@dataclass
-class CeVIOTimeline:
+class CeVIOTimeline(BaseModel):
     class Meta:
         name = "Timeline"
 
-    partition: Optional[str] = field(
+    partition: str | None = field(
         default=None,
         metadata={
             "name": "Partition",
             "type": "Attribute",
         },
     )
-    current_position: Optional[XmlTime] = field(
+    current_position: XmlTime | None = field(
         default=None,
         metadata={
             "name": "CurrentPosition",
             "type": "Attribute",
         },
     )
-    start_position: Optional[XmlTime] = field(
+    start_position: XmlTime | None = field(
         default=None,
         metadata={
             "name": "StartPosition",
             "type": "Attribute",
         },
     )
-    view_scale: Optional[CeVIOViewScale] = field(
+    end_position: XmlTime | None = field(
+        default=None,
+        metadata={
+            "name": "EndPosition",
+            "type": "Attribute",
+        },
+    )
+    view_scale: CeVIOViewScale | None = field(
         default=None,
         metadata={
             "name": "ViewScale",
@@ -779,27 +761,26 @@ class CeVIOTimeline:
     )
 
 
-@dataclass
-class CeVIOParameter:
+class CeVIOParameter(BaseModel):
     class Meta:
         name = "Parameter"
 
-    length: Optional[int] = field(
+    length: int | None = field(
         default=None,
         metadata={
             "name": "Length",
             "type": "Attribute",
         },
     )
-    data: list[Union[CeVIOData, float, Decimal, int]] = field(
+    data: list[CeVIOData | float | Decimal | int] = field(
         default_factory=list,
         metadata={
             "name": "Data",
             "type": "Element",
         },
     )
-    no_data: Optional[list[CeVIONoData]] = field(
-        default=None,
+    no_data: list[CeVIONoData] = field(
+        default_factory=list,
         metadata={
             "name": "NoData",
             "type": "Element",
@@ -807,54 +788,53 @@ class CeVIOParameter:
     )
 
 
-@dataclass
-class CeVIOParameters:
+class CeVIOParameters(BaseModel):
     class Meta:
         name = "Parameters"
 
-    timing: Optional[CeVIOParameter] = field(
+    timing: CeVIOParameter | None = field(
         default=None,
         metadata={
             "name": "Timing",
             "type": "Element",
         },
     )
-    log_f0: Optional[CeVIOParameter] = field(
+    log_f0: CeVIOParameter | None = field(
         default=None,
         metadata={
             "name": "LogF0",
             "type": "Element",
         },
     )
-    c0: Optional[CeVIOParameter] = field(
+    c0: CeVIOParameter | None = field(
         default=None,
         metadata={
             "name": "C0",
             "type": "Element",
         },
     )
-    vib_amp: Optional[CeVIOParameter] = field(
+    vib_amp: CeVIOParameter | None = field(
         default=None,
         metadata={
             "name": "VibAmp",
             "type": "Element",
         },
     )
-    vib_frq: Optional[CeVIOParameter] = field(
+    vib_frq: CeVIOParameter | None = field(
         default=None,
         metadata={
             "name": "VibFrq",
             "type": "Element",
         },
     )
-    alpha: Optional[CeVIOParameter] = field(
+    alpha: CeVIOParameter | None = field(
         default=None,
         metadata={
             "name": "Alpha",
             "type": "Element",
         },
     )
-    husky: Optional[CeVIOParameter] = field(
+    husky: CeVIOParameter | None = field(
         default=None,
         metadata={
             "name": "Husky",
@@ -863,26 +843,25 @@ class CeVIOParameters:
     )
 
 
-@dataclass
-class CeVIOSvss:
+class CeVIOSvss(BaseModel):
     class Meta:
         name = "SVSS"
 
-    version: Optional[str] = field(
+    version: str | None = field(
         default="3.0.5",
         metadata={
             "name": "Version",
             "type": "Attribute",
         },
     )
-    dictionary: Optional[CeVIODictionary] = field(
+    dictionary: CeVIODictionary | None = field(
         default_factory=CeVIODictionary,
         metadata={
             "name": "Dictionary",
             "type": "Element",
         },
     )
-    sound_sources: Optional[CeVIOSoundSources] = field(
+    sound_sources: CeVIOSoundSources = field(
         default_factory=CeVIOSoundSources,
         metadata={
             "name": "SoundSources",
@@ -891,26 +870,25 @@ class CeVIOSvss:
     )
 
 
-@dataclass
-class CeVIOGeneration:
+class CeVIOGeneration(BaseModel):
     class Meta:
         name = "Generation"
 
-    author: Optional[CeVIOAuthor] = field(
+    author: CeVIOAuthor | None = field(
         default_factory=CeVIOAuthor,
         metadata={
             "name": "Author",
             "type": "Element",
         },
     )
-    tts: Optional[CeVIOTts] = field(
+    tts: CeVIOTts | None = field(
         default_factory=CeVIOTts,
         metadata={
             "name": "TTS",
             "type": "Element",
         },
     )
-    svss: Optional[CeVIOSvss] = field(
+    svss: CeVIOSvss = field(
         default_factory=CeVIOSvss,
         metadata={
             "name": "SVSS",
@@ -919,47 +897,46 @@ class CeVIOGeneration:
     )
 
 
-@dataclass
-class CeVIOSong:
+class CeVIOSong(BaseModel):
     class Meta:
         name = "Song"
 
-    version: Optional[str] = field(
+    version: str | None = field(
         default="1.02",
         metadata={
             "name": "Version",
             "type": "Attribute",
         },
     )
-    common_keys: Optional[bool] = field(
+    common_keys: bool | None = field(
         default=None,
         metadata={
             "name": "CommonKeys",
             "type": "Attribute",
         },
     )
-    tempo: Optional[CeVIOTempo] = field(
+    tempo: CeVIOTempo | None = field(
         default=None,
         metadata={
             "name": "Tempo",
             "type": "Element",
         },
     )
-    beat: Optional[CeVIOBeat] = field(
+    beat: CeVIOBeat | None = field(
         default=None,
         metadata={
             "name": "Beat",
             "type": "Element",
         },
     )
-    score: Optional[CeVIOScore] = field(
+    score: CeVIOScore = field(
         default_factory=CeVIOScore,
         metadata={
             "name": "Score",
             "type": "Element",
         },
     )
-    parameter: Optional[CeVIOParameters] = field(
+    parameter: CeVIOParameters = field(
         default_factory=CeVIOParameters,
         metadata={
             "name": "Parameter",
@@ -968,37 +945,36 @@ class CeVIOSong:
     )
 
 
-@dataclass
-class CeVIOBaseUnit:
-    version: Optional[str] = field(
+class CeVIOBaseUnit(BaseModel):
+    version: str | None = field(
         default="1.0",
         metadata={
             "name": "Version",
             "type": "Attribute",
         },
     )
-    unit_id: Optional[str] = field(
+    unit_id: str | None = field(
         default="",
         metadata={
             "name": "Id",
             "type": "Attribute",
         },
     )
-    group: Optional[str] = field(
+    group: str | None = field(
         default=None,
         metadata={
             "name": "Group",
             "type": "Attribute",
         },
     )
-    start_time: Optional[XmlTime] = field(
+    start_time: XmlTime | None = field(
         default=None,
         metadata={
             "name": "StartTime",
             "type": "Attribute",
         },
     )
-    duration: Optional[XmlTime] = field(
+    duration: XmlTime | None = field(
         default=None,
         metadata={
             "name": "Duration",
@@ -1012,14 +988,14 @@ class CeVIOBaseUnit:
             "type": "Attribute",
         },
     )
-    text: Optional[str] = field(
+    text: str | None = field(
         default=None,
         metadata={
             "name": "Text",
             "type": "Attribute",
         },
     )
-    snap_shot: Optional[str] = field(
+    snap_shot: str | None = field(
         default=None,
         metadata={
             "name": "SnapShot",
@@ -1028,23 +1004,22 @@ class CeVIOBaseUnit:
     )
 
 
-@dataclass
 class CeVIOSongUnit(CeVIOBaseUnit):
-    song: Optional[CeVIOSong] = field(
-        default=None,
+    song: CeVIOSong = field(
+        default_factory=CeVIOSong,
         metadata={
             "name": "Song",
             "type": "Element",
         },
     )
-    cast_id: Optional[str] = field(
+    cast_id: str | None = field(
         default=None,
         metadata={
             "name": "CastId",
             "type": "Attribute",
         },
     )
-    language: Optional[str] = field(
+    language: str | None = field(
         default="Japanese",
         metadata={
             "name": "Language",
@@ -1053,12 +1028,11 @@ class CeVIOSongUnit(CeVIOBaseUnit):
     )
 
 
-@dataclass
-class CeVIOComponent:
+class CeVIOComponent(BaseModel):
     class Meta:
         name = "Component"
 
-    name: Optional[str] = field(
+    name: str | None = field(
         default=None,
         metadata={
             "name": "Name",
@@ -1066,7 +1040,7 @@ class CeVIOComponent:
             "required": True,
         },
     )
-    value: Optional[Decimal] = field(
+    value: Decimal | None = field(
         default=None,
         metadata={
             "name": "Value",
@@ -1076,12 +1050,11 @@ class CeVIOComponent:
     )
 
 
-@dataclass
-class CeVIOPhoneme:
+class CeVIOPhoneme(BaseModel):
     class Meta:
         name = "Phoneme"
 
-    data: Optional[str] = field(
+    data: str | None = field(
         default=None,
         metadata={
             "name": "Data",
@@ -1089,21 +1062,21 @@ class CeVIOPhoneme:
             "required": True,
         },
     )
-    volume: Optional[Union[Decimal, float]] = field(
+    volume: Decimal | float | None = field(
         default=None,
         metadata={
             "name": "Volume",
             "type": "Attribute",
         },
     )
-    speed: Optional[Union[float, Decimal]] = field(
+    speed: float | Decimal | None = field(
         default=None,
         metadata={
             "name": "Speed",
             "type": "Attribute",
         },
     )
-    tone: Optional[Union[Decimal, float]] = field(
+    tone: Decimal | float | None = field(
         default=None,
         metadata={
             "name": "Tone",
@@ -1112,12 +1085,11 @@ class CeVIOPhoneme:
     )
 
 
-@dataclass
-class CeVIODirection:
+class CeVIODirection(BaseModel):
     class Meta:
         name = "Direction"
 
-    volume: Optional[float] = field(
+    volume: float | None = field(
         default=None,
         metadata={
             "name": "Volume",
@@ -1125,7 +1097,7 @@ class CeVIODirection:
             "required": True,
         },
     )
-    speed: Optional[float] = field(
+    speed: float | None = field(
         default=None,
         metadata={
             "name": "Speed",
@@ -1133,7 +1105,7 @@ class CeVIODirection:
             "required": True,
         },
     )
-    tone: Optional[float] = field(
+    tone: float | None = field(
         default=None,
         metadata={
             "name": "Tone",
@@ -1141,7 +1113,7 @@ class CeVIODirection:
             "required": True,
         },
     )
-    alpha: Optional[float] = field(
+    alpha: float | None = field(
         default=None,
         metadata={
             "name": "Alpha",
@@ -1149,7 +1121,7 @@ class CeVIODirection:
             "required": True,
         },
     )
-    log_f0_scale: Optional[float] = field(
+    log_f0_scale: float | None = field(
         default=None,
         metadata={
             "name": "LogF0Scale",
@@ -1167,8 +1139,7 @@ class CeVIODirection:
     )
 
 
-@dataclass
-class CeVIOPhonemes:
+class CeVIOPhonemes(BaseModel):
     class Meta:
         name = "Phonemes"
 
@@ -1182,26 +1153,25 @@ class CeVIOPhonemes:
     )
 
 
-@dataclass
-class Word:
+class Word(BaseModel):
     class Meta:
         name = "word"
 
-    phoneme: Optional[str] = field(
+    phoneme: str | None = field(
         default=None,
         metadata={
             "type": "Attribute",
             "required": True,
         },
     )
-    pronunciation: Optional[str] = field(
+    pronunciation: str | None = field(
         default=None,
         metadata={
             "type": "Attribute",
             "required": True,
         },
     )
-    pos: Optional[str] = field(
+    pos: str | None = field(
         default=None,
         metadata={
             "type": "Attribute",
@@ -1210,8 +1180,7 @@ class Word:
     value: str = field(default="")
 
 
-@dataclass
-class AcousticPhrase:
+class AcousticPhrase(BaseModel):
     class Meta:
         name = "acoustic_phrase"
 
@@ -1223,8 +1192,7 @@ class AcousticPhrase:
     )
 
 
-@dataclass
-class Base:
+class Base(BaseModel):
     acoustic_phrase: list[AcousticPhrase] = field(
         default_factory=list,
         metadata={
@@ -1233,8 +1201,7 @@ class Base:
     )
 
 
-@dataclass
-class Edited:
+class Edited(BaseModel):
     acoustic_phrase: list[AcousticPhrase] = field(
         default_factory=list,
         metadata={
@@ -1243,12 +1210,11 @@ class Edited:
     )
 
 
-@dataclass
-class CeVIOMetadataEN:
+class CeVIOMetadataEN(BaseModel):
     class Meta:
         name = "Metadata_EN"
 
-    base: Optional[Base] = field(
+    base: Base | None = field(
         default=None,
         metadata={
             "name": "Base",
@@ -1256,7 +1222,7 @@ class CeVIOMetadataEN:
             "required": True,
         },
     )
-    edited: Optional[Edited] = field(
+    edited: Edited | None = field(
         default=None,
         metadata={
             "name": "Edited",
@@ -1265,23 +1231,22 @@ class CeVIOMetadataEN:
     )
 
 
-@dataclass
 class CeVIOTalkUnit(CeVIOBaseUnit):
-    metadata: Optional[str] = field(
+    metadata: str | None = field(
         default=None,
         metadata={
             "name": "Metadata",
             "type": "Element",
         },
     )
-    metadata_en: Optional[CeVIOMetadataEN] = field(
+    metadata_en: CeVIOMetadataEN | None = field(
         default=None,
         metadata={
             "name": "Metadata_EN",
             "type": "Element",
         },
     )
-    direction: Optional[CeVIODirection] = field(
+    direction: CeVIODirection | None = field(
         default=None,
         metadata={
             "name": "Direction",
@@ -1289,7 +1254,7 @@ class CeVIOTalkUnit(CeVIOBaseUnit):
             "required": True,
         },
     )
-    phonemes: Optional[CeVIOPhonemes] = field(
+    phonemes: CeVIOPhonemes | None = field(
         default=None,
         metadata={
             "name": "Phonemes",
@@ -1299,9 +1264,8 @@ class CeVIOTalkUnit(CeVIOBaseUnit):
     )
 
 
-@dataclass
 class CeVIOAudioUnit(CeVIOBaseUnit):
-    file_path: Optional[str] = field(
+    file_path: str | None = field(
         default=None,
         metadata={
             "name": "FilePath",
@@ -1310,14 +1274,12 @@ class CeVIOAudioUnit(CeVIOBaseUnit):
     )
 
 
-@dataclass
 class CeVIOUnit(CeVIOSongUnit, CeVIOTalkUnit, CeVIOAudioUnit):
     class Meta:
         name = "Unit"
 
 
-@dataclass
-class CeVIOUnits:
+class CeVIOUnits(BaseModel):
     class Meta:
         name = "Units"
 
@@ -1330,54 +1292,53 @@ class CeVIOUnits:
     )
 
 
-@dataclass
-class CeVIOScene:
+class CeVIOScene(BaseModel):
     class Meta:
         name = "Scene"
 
-    scene_id: Optional[str] = field(
+    scene_id: str | None = field(
         default="",
         metadata={
             "name": "Id",
             "type": "Attribute",
         },
     )
-    timeline: Optional[CeVIOTimeline] = field(
+    timeline: CeVIOTimeline | None = field(
         default=None,
         metadata={
             "name": "Timeline",
             "type": "Element",
         },
     )
-    talk_editor: Optional[CeVIOTalkEditor] = field(
+    talk_editor: CeVIOTalkEditor | None = field(
         default=None,
         metadata={
             "name": "TalkEditor",
             "type": "Element",
         },
     )
-    song_editor: Optional[CeVIOSongEditor] = field(
+    song_editor: CeVIOSongEditor | None = field(
         default=None,
         metadata={
             "name": "SongEditor",
             "type": "Element",
         },
     )
-    units: Optional[CeVIOUnits] = field(
+    units: CeVIOUnits = field(
         default_factory=CeVIOUnits,
         metadata={
             "name": "Units",
             "type": "Element",
         },
     )
-    groups: Optional[CeVIOGroups] = field(
+    groups: CeVIOGroups = field(
         default_factory=CeVIOGroups,
         metadata={
             "name": "Groups",
             "type": "Element",
         },
     )
-    sound_setting: Optional[CeVIOSoundSetting] = field(
+    sound_setting: CeVIOSoundSetting | None = field(
         default_factory=CeVIOSoundSetting,
         metadata={
             "name": "SoundSetting",
@@ -1386,19 +1347,18 @@ class CeVIOScene:
     )
 
 
-@dataclass
-class CeVIOSequence:
+class CeVIOSequence(BaseModel):
     class Meta:
         name = "Sequence"
 
-    sequence_id: Optional[str] = field(
+    sequence_id: str | None = field(
         default="",
         metadata={
             "name": "Id",
             "type": "Attribute",
         },
     )
-    scene: Optional[CeVIOScene] = field(
+    scene: CeVIOScene = field(
         default_factory=CeVIOScene,
         metadata={
             "name": "Scene",
@@ -1407,26 +1367,25 @@ class CeVIOSequence:
     )
 
 
-@dataclass
-class CeVIOCreativeStudioProject:
+class CeVIOCreativeStudioProject(BaseModel):
     class Meta:
         name = "Scenario"
 
-    code: Optional[str] = field(
+    code: str | None = field(
         default="7251BC4B6168E7B2992FA620BD3E1E77",
         metadata={
             "name": "Code",
             "type": "Attribute",
         },
     )
-    generation: Optional[CeVIOGeneration] = field(
+    generation: CeVIOGeneration = field(
         default_factory=CeVIOGeneration,
         metadata={
             "name": "Generation",
             "type": "Element",
         },
     )
-    sequence: Optional[CeVIOSequence] = field(
+    sequence: CeVIOSequence = field(
         default_factory=CeVIOSequence,
         metadata={
             "name": "Sequence",
