@@ -1,12 +1,12 @@
-import contextvars
+from contextvars import ContextVar
 
 from libresvip.core.lyric_phoneme.chinese import get_pinyin_series
-from libresvip.utils import gettext_lazy as _
+from libresvip.utils.translation import gettext_lazy as _
 
-from ..phoneme_dict import get_opencpop_dict
+from .phoneme_dict import get_opencpop_dict
 
-pinyin_list_ctx: list[str] = contextvars.ContextVar("pinyin_list")
-phoneme_table_ctx: dict[str, str] = contextvars.ContextVar("phoneme_table")
+pinyin_list_ctx: ContextVar[list[str]] = ContextVar("pinyin_list")
+phoneme_table_ctx: ContextVar[dict[str, str]] = ContextVar("phoneme_table")
 
 
 def split(pinyin: str) -> tuple[str, str]:
@@ -14,7 +14,7 @@ def split(pinyin: str) -> tuple[str, str]:
     if pinyin not in phoneme_table:
         raise ValueError(
             _(
-                "The selected dictionary does not contain the pronunciation “{}”. Please check the pronunciation or try another dictionary."
+                'The selected dictionary does not contain the pronunciation "{}". Please check the pronunciation or try another dictionary.'
             ).format(pinyin)
         )
 
