@@ -12,12 +12,12 @@ from .options import InputOptions, OutputOptions
 
 class GjgjConverter(plugin_base.SVSConverterBase):
     def load(self, path: pathlib.Path, options: InputOptions) -> Project:
-        gjgj_project = GjgjProject.model_validate_json(path.read_text(encoding="utf-8-sig"))
+        gjgj_project = GjgjProject.model_validate_json(path.read_bytes().decode("utf-8-sig"))
         return GjgjParser(options).parse_project(gjgj_project)
 
     def dump(self, path: pathlib.Path, project: Project, options: OutputOptions) -> None:
         gjgj_project = GjgjGenerator(options).generate_project(project)
-        path.write_text(
+        path.write_bytes(
             json.dumps(
                 gjgj_project.model_dump(
                     mode="json",
@@ -26,6 +26,5 @@ class GjgjConverter(plugin_base.SVSConverterBase):
                 ),
                 ensure_ascii=False,
                 separators=(",", ":"),
-            ),
-            encoding="utf-8-sig",
+            ).encode("utf-8-sig")
         )
