@@ -1,5 +1,4 @@
 from functools import partial
-from typing import Optional
 
 from libresvip.model.base import BaseModel
 
@@ -7,12 +6,12 @@ from libresvip.model.base import BaseModel
 class TimeTag(BaseModel):
     minute: int
     second: int
-    percent_second: int
+    milisecond: int
 
 
 class LyricLine(BaseModel):
     time_tags: list[TimeTag]
-    lyric: Optional[str] = None
+    lyric: str | None = None
 
 
 class InfoTag(BaseModel):
