@@ -11,13 +11,13 @@ LRC_TEMPLATE = Template(
 {% endfor %}\
 {% for lyric_line in lrc_model.lyric_lines %}\
 {% for time_tag in lyric_line.time_tags %}\
-[{{ (time_tag.minute).__str__().ljust(2, '0') }}:\
-{{ (time_tag.second).__str__().ljust(2, '0') }}.\
-{{ (time_tag.percent_second).__str__().ljust(3, '0') }}]{% endfor %}\
+[{{ (time_tag.minute).__str__().rjust(2, '0') }}:\
+{{ (time_tag.second).__str__().rjust(2, '0') }}.\
+{{ (time_tag.milisecond).__str__().rjust(3, '0') }}]{% endfor %}\
 {{ lyric_line.lyric }}\
 {% endfor %}"""
 )
 
 
-def render_lrc(lrc_model: LrcFile, output_path: pathlib.Path):
-    output_path.write_text(LRC_TEMPLATE.render(lrc_model=lrc_model), encoding="utf-8")
+def render_lrc(lrc_model: LrcFile, output_path: pathlib.Path) -> None:
+    output_path.write_bytes(LRC_TEMPLATE.render(lrc_model=lrc_model).encode("utf-8"))
