@@ -15,5 +15,5 @@ NN_TEMPLATE = Template(
 )
 
 
-def render_nn(nn_project: NNProject, output_path: pathlib.Path):
-    output_path.write_text(NN_TEMPLATE.render(nn_project=nn_project), encoding="utf-8")
+def render_nn(nn_project: NNProject, output_path: pathlib.Path) -> None:
+    output_path.write_bytes(NN_TEMPLATE.render(nn_project=nn_project).encode("utf-8"))
