@@ -2,8 +2,11 @@
 import dataclasses
 import threading
 from collections import ChainMap
+from collections.abc import MutableMapping
 from functools import cached_property
+from types import TracebackType
 
+from construct import Container
 from typing_extensions import Self
 
 from .binary_models import (
@@ -18,11 +21,11 @@ from .binary_models import (
 class NrbfIOBase:
     cur_thread_id: int = dataclasses.field(init=False)
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         self.cur_thread_id = threading.get_ident()
 
     @cached_property
-    def ref_map(self) -> ChainMap:
+    def ref_map(self) -> MutableMapping[int, MutableMapping[int, Container]]:
         return ChainMap(
             classes_by_id[self.cur_thread_id],
             objects_by_id[self.cur_thread_id],
@@ -31,7 +34,12 @@ class NrbfIOBase:
     def __enter__(self) -> Self:
         return self
 
-    def __exit__(self, exc_type, exc_value, traceback) -> None:
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        traceback: TracebackType | None,
+    ) -> None:
         classes_by_id.pop(self.cur_thread_id, None)
         objects_by_id.pop(self.cur_thread_id, None)
         libraries_by_id.pop(self.cur_thread_id, None)
