@@ -1,24 +1,30 @@
 import dataclasses
+import functools
 import math
 from collections.abc import Callable
 from typing import NamedTuple
 
 import more_itertools
+import portion
 
 from libresvip.core.exceptions import ParamsError
-from libresvip.utils import clamp, find_index
+from libresvip.core.time_interval import PiecewiseIntervalDict
+from libresvip.utils.music_math import clamp, linear_interpolation
+from libresvip.utils.search import find_index
 
 from .constants import MAX_BREAK
+from .interval_utils import position_to_ticks
 from .lambert_w import LambertW
+from .model import SVCurvePitchControl, SVPitchControl
 
 
 class NoteStruct(NamedTuple):
     key: int
     start: float
     end: float
-    slide_offset: float
-    slide_left: float
-    slide_right: float
+    portamento_offset: float
+    portamento_left: float
+    portamento_right: float
     depth_left: float
     depth_right: float
     vibrato_start: float
@@ -61,15 +67,15 @@ class SigmoidNode:
         self.start = _start
         self.end = _end
         self.center = _center
-        h = (_key_right - _key_left) * 100
+        h: float = (_key_right - _key_left) * 100
         a = 1 / (1 + math.exp(self.k))
         power = 0.75
 
         left = self.center - self.start
-        if left >= _radius:
+        if left >= _radius or left == 0:
             k_l = self.k
             h_l = h
-            d_l = 0
+            d_l = 0.0
         else:
             al = a * math.pow(_radius / left, power)
             bl = left / _radius
@@ -89,14 +95,14 @@ class SigmoidNode:
             / math.pow(1 + math.exp(-k_l / _radius * (x - self.center + d_l)), 2)
         )
 
-        r = self.end - self.center
-        if r >= _radius:
+        right = self.end - self.center
+        if right >= _radius or right == 0:
             k_r = self.k
             h_r = h
-            d_r = 0
+            d_r = 0.0
         else:
-            ar = a * math.pow(_radius / r, power)
-            br = r / _radius
+            ar = a * math.pow(_radius / right, power)
+            br = right / _radius
             cr = ar * br * self.k / (2 * ar - 1)
             k_r = ar / (2 * ar - 1) * self.k - 1 / br * LambertW.evaluate(cr * math.exp(cr), -1)
             h_r = h * k_r / (2 * k_r - self.k)
@@ -134,23 +140,21 @@ class BaseLayerGenerator:
         for current_note, next_note in more_itertools.pairwise(self.note_list):
             if current_note.key == next_note.key:
                 continue
-            if (
-                current_note.slide_right
-                and next_note.slide_left
-                and next_note.start - current_note.end <= MAX_BREAK
+            if (diameter := current_note.portamento_right + next_note.portamento_left) and (
+                next_note.start - current_note.end <= MAX_BREAK
             ):
                 start = clamp(
-                    current_note.end - current_note.slide_right + next_note.slide_offset,
+                    current_note.end - current_note.portamento_right + next_note.portamento_offset,
                     current_note.start,
                     current_note.end,
                 )
                 end = clamp(
-                    next_note.start + next_note.slide_left + next_note.slide_offset,
+                    next_note.start + next_note.portamento_left + next_note.portamento_offset,
                     next_note.start,
                     next_note.end,
                 )
                 mid = clamp(
-                    (current_note.end + next_note.start) / 2 + next_note.slide_offset,
+                    (current_note.end + next_note.start) / 2 + next_note.portamento_offset,
                     start,
                     end,
                 )
@@ -159,7 +163,7 @@ class BaseLayerGenerator:
                         _start=start,
                         _end=end,
                         _center=mid,
-                        _radius=(current_note.slide_right + next_note.slide_left) / 2,
+                        _radius=diameter / 2,
                         _key_left=current_note.key,
                         _key_right=next_note.key,
                     )
@@ -179,7 +183,7 @@ class BaseLayerGenerator:
 
     def pitch_at_secs(self, secs: float) -> float:
         query = [node for node in self.sigmoid_nodes if node.start <= secs < node.end]
-        if len(query) == 0:
+        if not query:
             on_note_index = find_index(self.note_list, lambda note: note.start <= secs < note.end)
             if on_note_index >= 0:
                 return self.note_list[on_note_index].key * 100
@@ -192,17 +196,17 @@ class BaseLayerGenerator:
             )
         elif len(query) == 1:
             return query[0].value_at_secs(secs)
-        elif len(query) == 2:
+        elif len(query) <= 3:
             first = query[0]
-            second = query[1]
-            width = first.end - second.start
-            bottom = first.value_at_secs(second.start)
-            top = second.value_at_secs(first.end)
-            diff1 = first.slope_at_secs(second.start)
-            diff2 = second.slope_at_secs(first.end)
-            return self.cubic_bezier(width, bottom, top, diff1, diff2)(secs - second.start)
+            last = query[-1]
+            width = first.end - last.start
+            bottom = first.value_at_secs(last.start)
+            top = last.value_at_secs(first.end)
+            diff1 = first.slope_at_secs(last.start)
+            diff2 = last.slope_at_secs(first.end)
+            return self.cubic_bezier(width, bottom, top, diff1, diff2)(secs - last.start)
         else:
-            msg = "More than two sigmoid nodes overlapped"
+            msg = "More than three sigmoid nodes overlapped"
             raise ParamsError(msg)
 
     @staticmethod
@@ -299,10 +303,7 @@ class GaussianNode:
                 )
 
     def value_at_secs(self, secs: float) -> float:
-        if secs < self.origin:
-            return self.gaussian_l(secs)
-        else:
-            return self.gaussian_r(secs)
+        return self.gaussian_l(secs) if secs < self.origin else self.gaussian_r(secs)
 
 
 @dataclasses.dataclass
@@ -311,7 +312,7 @@ class GaussianLayerGenerator:
     gaussian_nodes: list[GaussianNode] = dataclasses.field(default_factory=list)
 
     def __post_init__(self, _note_list: list[NoteStruct]) -> None:
-        if len(_note_list) == 0:
+        if not _note_list:
             return
         current_note = _note_list[0]
         self.gaussian_nodes.append(
@@ -319,7 +320,7 @@ class GaussianLayerGenerator:
                 is_end_point=True,
                 _origin=current_note.start,
                 _depth=-current_note.depth_left,
-                _width=current_note.slide_left,
+                _width=current_note.portamento_left,
                 _length_l=math.nan,
                 _length_r=current_note.end - current_note.start,
             )
@@ -331,7 +332,7 @@ class GaussianLayerGenerator:
                         is_end_point=True,
                         _origin=current_note.end,
                         _depth=current_note.depth_right,
-                        _width=current_note.slide_left,
+                        _width=current_note.portamento_left,
                         _length_l=current_note.end - current_note.start,
                         _length_r=math.nan,
                     )
@@ -341,7 +342,7 @@ class GaussianLayerGenerator:
                         is_end_point=True,
                         _origin=next_note.start,
                         _depth=-next_note.depth_left,
-                        _width=next_note.slide_left,
+                        _width=next_note.portamento_left,
                         _length_l=math.nan,
                         _length_r=next_note.end - next_note.start,
                     )
@@ -349,7 +350,7 @@ class GaussianLayerGenerator:
             else:
                 middle = (current_note.end + next_note.start) / 2
                 origin = clamp(
-                    middle + current_note.slide_offset,
+                    middle + current_note.portamento_offset,
                     current_note.start,
                     current_note.end,
                 )
@@ -364,7 +365,7 @@ class GaussianLayerGenerator:
                         is_end_point=False,
                         _origin=origin,
                         _depth=depth_l,
-                        _width=-current_note.slide_right,
+                        _width=-current_note.portamento_right,
                         _length_l=origin - current_note.start,
                         _length_r=next_note.end - origin,
                     )
@@ -380,7 +381,7 @@ class GaussianLayerGenerator:
                         is_end_point=False,
                         _origin=origin,
                         _depth=depth_r,
-                        _width=next_note.slide_left,
+                        _width=next_note.portamento_left,
                         _length_l=origin - current_note.start,
                         _length_r=next_note.end - origin,
                     )
@@ -390,7 +391,7 @@ class GaussianLayerGenerator:
                 is_end_point=True,
                 _origin=_note_list[-1].end,
                 _depth=-_note_list[-1].depth_right,
-                _width=_note_list[-1].slide_left,
+                _width=_note_list[-1].portamento_left,
                 _length_l=_note_list[-1].end - _note_list[-1].start,
                 _length_r=math.nan,
             )
@@ -450,7 +451,7 @@ class VibratoLayerGenerator:
                 continue
             if i < len(_note_list) - 1 and _note_list[i + 1].start - end < MAX_BREAK:
                 end += min(
-                    _note_list[i + 1].slide_offset,
+                    _note_list[i + 1].portamento_offset,
                     min(
                         _note_list[i + 1].vibrato_start,
                         _note_list[i + 1].end - _note_list[i + 1].start,
@@ -474,3 +475,36 @@ class VibratoLayerGenerator:
         return sum(
             node.value_at_secs(secs) for node in self.vibrato_nodes if node.start <= secs < node.end
         )
+
+
+@dataclasses.dataclass
+class PitchControlLayerGenerator:
+    _pitch_controls: dataclasses.InitVar[list[SVPitchControl]]
+    interval_dict: PiecewiseIntervalDict = dataclasses.field(default_factory=PiecewiseIntervalDict)
+
+    def __post_init__(self, _pitch_controls: list[SVPitchControl]) -> None:
+        for pitch_control in _pitch_controls:
+            if isinstance(pitch_control, SVCurvePitchControl) and len(pitch_control.points):
+                prev_point = pitch_control.points.root[0]
+                base_position = position_to_ticks(pitch_control.pos)
+                prev_ticks = position_to_ticks(prev_point.offset) + base_position
+                prev_value = (pitch_control.pitch + prev_point.value) * 100
+                self.interval_dict[portion.singleton(prev_ticks)] = prev_value
+                for point in pitch_control.points.root[1:]:
+                    ticks = position_to_ticks(point.offset) + base_position
+                    value = (pitch_control.pitch + point.value) * 100
+                    self.interval_dict[
+                        portion.openclosed(
+                            prev_ticks,
+                            ticks,
+                        )
+                    ] = functools.partial(
+                        linear_interpolation,  # type: ignore[call-arg]
+                        start=(prev_ticks, prev_value),
+                        end=(ticks, value),
+                    )
+                    prev_ticks = ticks
+                    prev_value = value
+
+    def value_at_ticks(self, ticks: int) -> float | None:
+        return self.interval_dict.get(ticks)
