@@ -3,10 +3,10 @@ from __future__ import annotations
 import re
 import sys
 from itertools import chain
-from typing import Literal, NamedTuple, Optional, Union
-from uuid import uuid4
+from typing import Annotated, Any, Literal, NamedTuple
 
-from more_itertools import chunked
+import zhon
+from more_itertools import batched
 from pydantic import (
     Field,
     FieldSerializationInfo,
@@ -14,20 +14,73 @@ from pydantic import (
     ValidationInfo,
     field_serializer,
     field_validator,
+    model_validator,
 )
+from retrie.retrie import Blacklist
+from typing_extensions import Self
 
 from libresvip.core.constants import DEFAULT_PHONEME
-from libresvip.core.lyric_phoneme.chinese import CHINESE_RE
 from libresvip.core.time_interval import RangeInterval
 from libresvip.model.base import BaseModel, Note
 from libresvip.model.point import PointList
+from libresvip.utils.audio import audio_path_validator
+from libresvip.utils.text import uuid_str
 
 from . import constants
 from .interval_utils import position_to_ticks
 
-
-def uuid_str() -> str:
-    return str(uuid4())
+symbols_blacklist = Blacklist(
+    [
+        "(",
+        ")",
+        "[",
+        "]",
+        "{",
+        "}",
+        "（",
+        "）",
+        "<",
+        ">",
+        "《",
+        "》",
+        "―",
+        "—",
+        "*",
+        "×",
+        "!",
+        "！",
+        "?",
+        "？",
+        ":",
+        "：",
+        "·",
+        "•",
+        "。",
+        ",",
+        "，",
+        ";",
+        "；",
+        "^",
+        "`",
+        '"',
+        "‘",
+        "’",
+        "“",
+        "”",
+        "=",
+        "、",
+        "_",
+        "$",
+        "%",
+        "~",
+        "@",
+        "#",
+        "…",
+        "&",
+        "￥",
+    ],
+    match_substrings=True,
+)
 
 
 class SVPoint(NamedTuple):
@@ -40,23 +93,25 @@ class SVPoints(PointList[SVPoint], RootModel[list[SVPoint]]):
 
 
 class SVBaseAttributes(BaseModel):
-    t_f0_left: Optional[float] = Field(None, alias="tF0Left")
-    t_f0_right: Optional[float] = Field(None, alias="tF0Right")
-    d_f0_left: Optional[float] = Field(None, alias="dF0Left")
-    d_f0_right: Optional[float] = Field(None, alias="dF0Right")
-    t_f0_vbr_start: Optional[float] = Field(None, alias="tF0VbrStart")
-    t_f0_vbr_left: Optional[float] = Field(None, alias="tF0VbrLeft")
-    t_f0_vbr_right: Optional[float] = Field(None, alias="tF0VbrRight")
-    d_f0_vbr: Optional[float] = Field(None, alias="dF0Vbr")
-    f_f0_vbr: Optional[float] = Field(None, alias="fF0Vbr")
-    param_loudness: Optional[float] = Field(None, alias="paramLoudness")
-    param_tension: Optional[float] = Field(None, alias="paramTension")
-    param_breathiness: Optional[float] = Field(None, alias="paramBreathiness")
-    param_gender: Optional[float] = Field(None, alias="paramGender")
-    param_tone_shift: Optional[float] = Field(None, alias="paramToneShift")
-    improvise_attack_release: Optional[bool] = Field(None, alias="improviseAttackRelease")
-    language_override: Optional[str] = Field(None, alias="languageOverride")
-    phoneset_override: Optional[str] = Field(None, alias="phonesetOverride")
+    t_f0_left: float | None = Field(None, alias="tF0Left")
+    t_f0_right: float | None = Field(None, alias="tF0Right")
+    d_f0_left: float | None = Field(None, alias="dF0Left")
+    d_f0_right: float | None = Field(None, alias="dF0Right")
+    t_f0_vbr_start: float | None = Field(None, alias="tF0VbrStart")
+    t_f0_vbr_left: float | None = Field(None, alias="tF0VbrLeft")
+    t_f0_vbr_right: float | None = Field(None, alias="tF0VbrRight")
+    d_f0_vbr: float | None = Field(None, alias="dF0Vbr")
+    f_f0_vbr: float | None = Field(None, alias="fF0Vbr")
+    param_loudness: float | None = Field(None, alias="paramLoudness")
+    param_tension: float | None = Field(None, alias="paramTension")
+    param_breathiness: float | None = Field(None, alias="paramBreathiness")
+    param_gender: float | None = Field(None, alias="paramGender")
+    param_tone_shift: float | None = Field(None, alias="paramToneShift")
+    improvise_attack_release: bool | None = Field(None, alias="improviseAttackRelease")
+    language_override: str | None = Field(None, alias="languageOverride")
+    phoneset_override: str | None = Field(None, alias="phonesetOverride")
+    transpose_cents: float | None = Field(None, alias="transposeCents")
+    transpose_semitones: float | None = Field(None, alias="transposeSemitones")
 
 
 class SVMeter(BaseModel):
@@ -73,23 +128,27 @@ class SVTempo(BaseModel):
 class SVTime(BaseModel):
     meter: list[SVMeter] = Field(default_factory=list)
     tempo: list[SVTempo] = Field(default_factory=list)
+    start_time_seconds: float | None = Field(None, alias="startTimeSeconds")
 
 
-class SVParamCurve(BaseModel):
-    mode: Literal["linear", "cubic", "cosine", "sigmoid"] = Field("linear")
+class SVBasePoints(BaseModel):
     points: SVPoints = Field(default_factory=SVPoints)
 
     @field_validator("points", mode="before")
     @classmethod
     def validate_points(cls, points: list[float], _info: ValidationInfo) -> SVPoints:
         if _info.mode == "json":
-            return SVPoints(root=[SVPoint(*each) for each in chunked(points, 2)])
+            return SVPoints(root=[SVPoint._make(each) for each in batched(points, 2)])
         return SVPoints(root=points)
 
     @field_serializer("points", when_used="json")
     def serialize_points(self, points: SVPoints, _info: FieldSerializationInfo) -> list[float]:
         return list(chain.from_iterable(points.root))
 
+
+class SVParamCurve(SVBasePoints):
+    mode: Literal["linear", "cubic", "cosine", "sigmoid"] = Field("linear")
+
     def edited_range(self, default_value: float = 0.0) -> RangeInterval:
         tolerance = 1e-6
         interval = RangeInterval()
@@ -134,27 +193,73 @@ class SVParamCurve(BaseModel):
 
 class SVParamTake(BaseModel):
     id_value: int = Field(alias="id")
-    expr: float
+    seed_duration: int | None = Field(None, alias="seedDuration")
+    seed_pitch: int | None = Field(None, alias="seedPitch")
+    seed_timbre: int | None = Field(None, alias="seedTimbre")
+    expr: float | None = None
+    enh: float | None = None
     liked: bool = False
 
 
+class SVBasePitchControl(BaseModel):
+    pos: int
+    pitch: float
+    id_value: str = Field(alias="id")
+
+
+class SVPointPitchControl(SVBasePitchControl):
+    type_: Literal["point"] = Field("point", alias="type")
+
+
+class SVCurvePitchControl(SVBasePitchControl, SVBasePoints):
+    type_: Literal["curve"] = Field("curve", alias="type")
+
+
+SVPitchControl = Annotated[
+    SVPointPitchControl | SVCurvePitchControl,
+    Field(discriminator="type_"),
+]
+
+
 class SVParamTakes(BaseModel):
     active_take_id: int = Field(alias="activeTakeId")
     takes: list[SVParamTake] = Field(default_factory=list)
 
 
+class SVPhonemeAttribute(BaseModel):
+    left_offset: float | None = Field(None, alias="leftOffset")
+    strength: float = 0
+    alt: int = 0
+    position: float | None = None
+    activity: float | None = None
+
+
 class SVNoteAttributes(SVBaseAttributes):
-    t_f0_offset: Optional[float] = Field(None, alias="tF0Offset")
-    p_f0_vbr: Optional[float] = Field(None, alias="pF0Vbr")
-    d_f0_jitter: Optional[float] = Field(None, alias="dF0Jitter")
-    t_note_offset: Optional[float] = Field(None, alias="tNoteOffset")
-    dur: Optional[list[float]] = None
-    alt: Optional[list[float]] = None
-    expr_group: Optional[str] = Field(None, alias="exprGroup")
-    strength: Optional[list[float]] = None
-    r_tone: Optional[float] = Field(None, alias="rTone")
-    r_intonation: Optional[float] = Field(None, alias="rIntonation")
-    even_syllable_duration: Optional[float] = Field(None, alias="evenSyllableDuration")
+    t_f0_left: float | None = Field(None, alias="tF0Left")
+    t_f0_right: float | None = Field(None, alias="tF0Right")
+    d_f0_left: float | None = Field(None, alias="dF0Left")
+    d_f0_right: float | None = Field(None, alias="dF0Right")
+    t_f0_vbr_start: float | None = Field(None, alias="tF0VbrStart")
+    t_f0_vbr_left: float | None = Field(None, alias="tF0VbrLeft")
+    t_f0_vbr_right: float | None = Field(None, alias="tF0VbrRight")
+    d_f0_vbr: float | None = Field(None, alias="dF0Vbr")
+    d_f0_vbr_mod: float | None = Field(None, alias="dF0VbrMod")
+    f_f0_vbr: float | None = Field(None, alias="fF0Vbr")
+    t_f0_offset: float | None = Field(None, alias="tF0Offset")
+    p_f0_vbr: float | None = Field(None, alias="pF0Vbr")
+    d_f0_jitter: float | None = Field(None, alias="dF0Jitter")
+    t_note_offset: float | None = Field(None, alias="tNoteOffset")
+    dur: list[float] | None = None
+    alt: list[int] | None = None
+    expr_group: str | None = Field(None, alias="exprGroup")
+    exp_value_x: float | None = Field(None, alias="expValueX")
+    exp_value_y: float | None = Field(None, alias="expValueY")
+    strength: list[float] | None = None
+    r_tone: float | None = Field(None, alias="rTone")
+    r_intonation: float | None = Field(None, alias="rIntonation")
+    even_syllable_duration: float | None = Field(None, alias="evenSyllableDuration")
+    phonemes: list[SVPhonemeAttribute] | None = None
+    muted: bool | None = None
 
     def _get_transition_offset(self) -> float:
         return constants.DEFAULT_PITCH_TRANSITION if self.t_f0_offset is None else self.t_f0_offset
@@ -162,23 +267,23 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_transition_offset(self, value: float) -> None:
         self.t_f0_offset = value
 
-    transition_offset = property(_get_transition_offset, _set_transition_offset)  # type: ignore [pydantic-field]
+    transition_offset = property(_get_transition_offset, _set_transition_offset)
 
-    def _get_slide_left(self) -> float:
-        return constants.DEFAULT_PITCH_SLIDE if self.t_f0_left is None else self.t_f0_left
+    def _get_portamento_left(self) -> float:
+        return constants.DEFAULT_PITCH_PORTAMENTO if self.t_f0_left is None else self.t_f0_left
 
-    def _set_slide_left(self, value: float) -> None:
+    def _set_portamento_left(self, value: float) -> None:
         self.t_f0_left = value
 
-    slide_left = property(_get_slide_left, _set_slide_left)  # type: ignore [pydantic-field]
+    portamento_left = property(_get_portamento_left, _set_portamento_left)
 
-    def _get_slide_right(self) -> float:
-        return constants.DEFAULT_PITCH_SLIDE if self.t_f0_right is None else self.t_f0_right
+    def _get_portamento_right(self) -> float:
+        return constants.DEFAULT_PITCH_PORTAMENTO if self.t_f0_right is None else self.t_f0_right
 
-    def _set_slide_right(self, value: float) -> None:
+    def _set_portamento_right(self, value: float) -> None:
         self.t_f0_right = value
 
-    slide_right = property(_get_slide_right, _set_slide_right)  # type: ignore [pydantic-field]
+    portamento_right = property(_get_portamento_right, _set_portamento_right)
 
     def _get_depth_left(self) -> float:
         return constants.DEFAULT_PITCH_DEPTH if self.d_f0_left is None else self.d_f0_left
@@ -186,7 +291,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_depth_left(self, value: float) -> None:
         self.d_f0_left = value
 
-    depth_left = property(_get_depth_left, _set_depth_left)  # type: ignore [pydantic-field]
+    depth_left = property(_get_depth_left, _set_depth_left)
 
     def _get_depth_right(self) -> float:
         return constants.DEFAULT_PITCH_DEPTH if self.d_f0_right is None else self.d_f0_right
@@ -194,7 +299,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_depth_right(self, value: float) -> None:
         self.d_f0_right = value
 
-    depth_right = property(_get_depth_right, _set_depth_right)  # type: ignore [pydantic-field]
+    depth_right = property(_get_depth_right, _set_depth_right)
 
     def _get_vibrato_start(self) -> float:
         return (
@@ -204,7 +309,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_vibrato_start(self, value: float) -> None:
         self.t_f0_vbr_start = value
 
-    vibrato_start = property(_get_vibrato_start, _set_vibrato_start)  # type: ignore [pydantic-field]
+    vibrato_start = property(_get_vibrato_start, _set_vibrato_start)
 
     def _get_vibrato_left(self) -> float:
         return constants.DEFAULT_VIBRATO_FADE if self.t_f0_vbr_left is None else self.t_f0_vbr_left
@@ -212,7 +317,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_vibrato_left(self, value: float) -> None:
         self.t_f0_vbr_left = value
 
-    vibrato_left = property(_get_vibrato_left, _set_vibrato_left)  # type: ignore [pydantic-field]
+    vibrato_left = property(_get_vibrato_left, _set_vibrato_left)
 
     def _get_vibrato_right(self) -> float:
         return (
@@ -222,7 +327,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_vibrato_right(self, value: float) -> None:
         self.t_f0_vbr_right = value
 
-    vibrato_right = property(_get_vibrato_right, _set_vibrato_right)  # type: ignore [pydantic-field]
+    vibrato_right = property(_get_vibrato_right, _set_vibrato_right)
 
     def _get_vibrato_depth(self) -> float:
         return constants.DEFAULT_VIBRATO_DEPTH if self.d_f0_vbr is None else self.d_f0_vbr
@@ -230,7 +335,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_vibrato_depth(self, value: float) -> None:
         self.d_f0_vbr = value
 
-    vibrato_depth = property(_get_vibrato_depth, _set_vibrato_depth)  # type: ignore [pydantic-field]
+    vibrato_depth = property(_get_vibrato_depth, _set_vibrato_depth)
 
     def _get_vibrato_frequency(self) -> float:
         return constants.DEFAULT_VIBRATO_FREQUENCY if self.f_f0_vbr is None else self.f_f0_vbr
@@ -238,7 +343,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_vibrato_frequency(self, value: float) -> None:
         self.f_f0_vbr = value
 
-    vibrato_frequency = property(_get_vibrato_frequency, _set_vibrato_frequency)  # type: ignore [pydantic-field]
+    vibrato_frequency = property(_get_vibrato_frequency, _set_vibrato_frequency)
 
     def _get_vibrato_phase(self) -> float:
         return constants.DEFAULT_VIBRATO_PHASE if self.p_f0_vbr is None else self.p_f0_vbr
@@ -246,7 +351,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_vibrato_phase(self, value: float) -> None:
         self.p_f0_vbr = value
 
-    vibrato_phase = property(_get_vibrato_phase, _set_vibrato_phase)  # type: ignore [pydantic-field]
+    vibrato_phase = property(_get_vibrato_phase, _set_vibrato_phase)
 
     def _get_vibrato_jitter(self) -> float:
         return constants.DEFAULT_VIBRATO_JITTER if self.d_f0_jitter is None else self.d_f0_jitter
@@ -254,7 +359,7 @@ class SVNoteAttributes(SVBaseAttributes):
     def _set_vibrato_jitter(self, value: float) -> None:
         self.d_f0_jitter = value
 
-    vibrato_jitter = property(_get_vibrato_jitter, _set_vibrato_jitter)  # type: ignore [pydantic-field]
+    vibrato_jitter = property(_get_vibrato_jitter, _set_vibrato_jitter)
 
     def set_phone_duration(self, index: int, duration: float) -> None:
         if self.dur is None:
@@ -283,8 +388,8 @@ class SVNoteAttributes(SVBaseAttributes):
             transition_edited &= any(
                 x >= tolerance
                 for x in (
-                    abs(self.slide_left - constants.DEFAULT_PITCH_SLIDE),
-                    abs(self.slide_right - constants.DEFAULT_PITCH_SLIDE),
+                    abs(self.portamento_left - constants.DEFAULT_PITCH_PORTAMENTO),
+                    abs(self.portamento_right - constants.DEFAULT_PITCH_PORTAMENTO),
                     abs(self.depth_left - constants.DEFAULT_PITCH_DEPTH),
                     abs(self.depth_right - constants.DEFAULT_PITCH_DEPTH),
                 )
@@ -315,35 +420,46 @@ class SVNote(BaseModel):
     lyrics: str = ""
     phonemes: str = ""
     pitch: int
-    detune: Optional[int] = None
-    accent: Optional[str] = None
+    detune: int | None = None
+    accent: str | None = None
     attributes: SVNoteAttributes = Field(default_factory=SVNoteAttributes)
-    system_attributes: Optional[SVNoteAttributes] = Field(None, alias="systemAttributes")
-    pitch_takes: Optional[SVParamTakes] = Field(None, alias="pitchTakes")
-    timbre_takes: Optional[SVParamTakes] = Field(None, alias="timbreTakes")
-    musical_type: Optional[Literal["singing", "rap"]] = Field("singing", alias="musicalType")
-    instant_mode: Optional[bool] = Field(None, alias="instantMode")
-
-    def cover_range(self) -> RangeInterval:
-        return RangeInterval([(self.onset, self.onset + self.duration)])
+    system_attributes: SVNoteAttributes | None = Field(None, alias="systemAttributes")
+    takes: SVParamTakes | None = None
+    pitch_takes: SVParamTakes | None = Field(None, alias="pitchTakes")
+    timbre_takes: SVParamTakes | None = Field(None, alias="timbreTakes")
+    musical_type: Literal["singing", "rap"] | None = Field("singing", alias="musicalType")
+    instant_mode: bool | None = Field(None, alias="instantMode")
 
     def merge_attributes(self, attributes: SVNoteAttributes) -> None:
         ori_dict = self.attributes.model_dump(
-            by_alias=True, exclude_none=True, exclude_unset=True, exclude_defaults=True
+            by_alias=True,
+            exclude_none=True,
+            exclude_unset=True,
+            exclude_defaults=True,
         )
         new_dict = attributes.model_dump(
-            by_alias=True, exclude_none=True, exclude_unset=True, exclude_defaults=True
+            by_alias=True,
+            exclude_none=True,
+            exclude_unset=True,
+            exclude_defaults=True,
         )
         ori_dict.update({k: v for k, v in new_dict.items() if k not in ori_dict})
         self.attributes = SVNoteAttributes.model_validate(ori_dict)
 
+    @model_validator(mode="after")
+    def _merge_system_attribute(self) -> Self:
+        if self.system_attributes is not None:
+            self.merge_attributes(self.system_attributes)
+        return self
+
     def pitch_edited(
         self,
         regard_default_vibrato_as_unedited: bool = True,
         consider_instant_pitch_mode: bool = True,
     ) -> bool:
         return self.attributes.pitch_edited(
-            regard_default_vibrato_as_unedited, consider_instant_pitch_mode
+            regard_default_vibrato_as_unedited,
+            consider_instant_pitch_mode and self.instant_mode is not False,
         )
 
     def __add__(self, blick_offset: int) -> SVNote:
@@ -353,18 +469,17 @@ class SVNote(BaseModel):
         return self.model_copy(deep=True, update={"pitch": self.pitch + pitch_offset})
 
     @staticmethod
-    def normalize_lyric(note: Note) -> str:
+    def normalize_lyric(lyric: str) -> str:
+        return symbols_blacklist.cleanse_text(lyric).strip()
+
+    @classmethod
+    def normalize_phoneme(cls, note: Note) -> str:
         if note.pronunciation:
             return note.pronunciation
-        elif valid_chars := re.sub(
-            r"[\s\(\)\[\]\{\}\^_*×――—（）$%~!@#$…&%￥—+=<>《》!！??？:：•`·、。，；,.;\"‘’“”]",
-            "",
-            note.lyric,
-        ):
-            if (hanzi := CHINESE_RE.search(valid_chars)) is not None:
-                return hanzi.group(0)
-            else:
-                return valid_chars
+        elif (hanzi := re.search(rf"[{zhon.hanzi.characters}]+", note.lyric)) is not None:
+            return hanzi[0]
+        elif valid_chars := cls.normalize_lyric(note.lyric):
+            return valid_chars.lstrip(".")
         else:
             return DEFAULT_PHONEME
 
@@ -377,7 +492,7 @@ class SVRenderConfig(BaseModel):
     num_channels: int = Field(1, alias="numChannels")
     sample_rate: int = Field(44100, alias="sampleRate")
     export_mix_down: bool = Field(True, alias="exportMixDown")
-    export_pitch: Optional[bool] = Field(False, alias="exportPitch")
+    export_pitch: bool | None = Field(False, alias="exportPitch")
 
 
 class SVParameters(BaseModel):
@@ -392,23 +507,37 @@ class SVParameters(BaseModel):
         default_factory=SVParamCurve, alias="vibratoEnv", title="颤音包络"
     )
     voicing: SVParamCurve = Field(default_factory=SVParamCurve, title="发声")
-    tone_shift: Optional[SVParamCurve] = Field(
+    tone_shift: SVParamCurve | None = Field(
         default_factory=SVParamCurve, alias="toneShift", title="音区偏移"
     )
+    mouth_opening: SVParamCurve | None = Field(
+        default_factory=SVParamCurve, alias="mouthOpening", title="口型"
+    )
 
     def __add__(self, offset: int) -> SVParameters:
         new_params = self.model_copy(deep=True)
-        for key in new_params.model_fields:
+        for key in type(self).model_fields:
             if (val := getattr(new_params, key, None)) is not None:
                 setattr(new_params, key, val + offset)
         return new_params
 
 
 class SVVoice(SVBaseAttributes):
+    t_f0_left: float | None = Field(0.07, alias="tF0Left")
+    t_f0_right: float | None = Field(0.07, alias="tF0Right")
+    d_f0_left: float | None = Field(0.15, alias="dF0Left")
+    d_f0_right: float | None = Field(0.15, alias="dF0Right")
+    t_f0_vbr_start: float | None = Field(0.25, alias="tF0VbrStart")
+    t_f0_vbr_left: float | None = Field(0.2, alias="tF0VbrLeft")
+    t_f0_vbr_right: float | None = Field(0.2, alias="tF0VbrRight")
+    d_f0_vbr: float | None = Field(1.0, alias="dF0Vbr")
+    f_f0_vbr: float | None = Field(5.5, alias="fF0Vbr")
     vocal_mode_inherited: bool = Field(True, alias="vocalModeInherited")
     vocal_mode_preset: str = Field("", alias="vocalModePreset")
-    vocal_mode_params: Optional[dict[str, float]] = Field(None, alias="vocalModeParams")
-    render_mode: Optional[str] = Field(None, alias="renderMode")
+    vocal_mode_params: dict[str, float | dict[str, float]] | None = Field(
+        None, alias="vocalModeParams"
+    )
+    render_mode: str | None = Field(None, alias="renderMode")
 
     def to_attributes(self) -> SVNoteAttributes:
         voice_dict = self.model_dump(
@@ -429,27 +558,36 @@ class SVVoice(SVBaseAttributes):
 class SVAudio(BaseModel):
     filename: str = ""
     duration: float
+    bpm: float | None = None
+    alternative_bpms: list[float] | None = Field(None, alias="alternativeBPMs")
+    beat_locations: list[float] | None = Field(None, alias="beatLocations")
+
+    validate_filename = field_validator("filename", mode="before")(audio_path_validator)
 
 
 class SVDatabase(BaseModel):
     name: str = ""
     language: str = "mandarin"
     phoneset: str = "xsampa"
-    version: Optional[Union[str, int]] = None
-    language_override: Optional[str] = Field(None, alias="languageOverride")
-    phoneset_override: Optional[str] = Field(None, alias="phonesetOverride")
+    version: str | int | None = None
+    language_override: str | None = Field(None, alias="languageOverride")
+    phoneset_override: str | None = Field(None, alias="phonesetOverride")
     backend_type: str = Field("", alias="backendType")
 
 
 class SVRef(BaseModel):
-    audio: Optional[SVAudio] = None
+    audio: SVAudio | None = None
+    blick_absolute_begin: int | None = Field(0, alias="blickAbsoluteBegin")
+    blick_absolute_end: int | None = Field(-1, alias="blickAbsoluteEnd")
     blick_offset: int = Field(default=0, alias="blickOffset")
     pitch_offset: int = Field(default=0, alias="pitchOffset")
-    pitch_takes: Optional[SVParamTakes] = Field(None, alias="pitchTakes")
-    timbre_takes: Optional[SVParamTakes] = Field(None, alias="timbreTakes")
+    takes: SVParamTakes | None = None
+    pitch_takes: SVParamTakes | None = Field(None, alias="pitchTakes")
+    timbre_takes: SVParamTakes | None = Field(None, alias="timbreTakes")
     database: SVDatabase = Field(default_factory=SVDatabase)
     dictionary: str = ""
     voice: SVVoice = Field(default_factory=SVVoice)
+    voice_preset_name: str | None = Field(None, alias="voicePresetName")
     group_id: str = Field(default_factory=uuid_str, alias="groupID")
     is_instrumental: bool = Field(default=False, alias="isInstrumental")
     system_pitch_delta: SVParamCurve = Field(default_factory=SVParamCurve, alias="systemPitchDelta")
@@ -461,11 +599,14 @@ class SVGroup(BaseModel):
     parameters: SVParameters = Field(default_factory=SVParameters)
     uuid: str = Field(default_factory=uuid_str)
     vocal_modes: dict[str, SVParamCurve] = Field(default_factory=dict, alias="vocalModes")
+    pitch_controls: list[SVPitchControl] = Field(default_factory=list, alias="pitchControls")
 
     @field_validator("notes", mode="before")
     @classmethod
-    def validate_notes(cls, v: list[dict], _info: ValidationInfo) -> list[dict]:
-        return [note for note in v if note["onset"] >= 0]
+    def validate_notes(cls, v: list[dict[str, Any]], _info: ValidationInfo) -> list[dict[str, Any]]:
+        if _info.mode == "json":
+            return [note for note in v if note["onset"] >= 0]
+        return v
 
     def overlapped_with(self, other: SVGroup) -> bool:
         for note in self.notes:
@@ -480,18 +621,20 @@ class SVGroup(BaseModel):
         return False
 
     def __add__(self, blick_offset: int) -> SVGroup:
-        new_group = self.model_copy(deep=True)
-        new_group.notes = [
-            note + blick_offset for note in self.notes if note.onset + blick_offset >= 0
-        ]
-        new_group.parameters += blick_offset
-        return new_group
+        return self.model_copy(
+            deep=True,
+            update={
+                "notes": [
+                    note + blick_offset for note in self.notes if note.onset + blick_offset >= 0
+                ],
+                "parameters": self.parameters + blick_offset,
+            },
+        )
 
     def __xor__(self, pitch_offset: int) -> SVGroup:
-        new_group = self.model_copy(deep=True)
-        for note in new_group.notes:
-            note ^= pitch_offset
-        return new_group
+        return self.model_copy(
+            deep=True, update={"notes": [note ^ pitch_offset for note in self.notes]}
+        )
 
 
 class SVMixer(BaseModel):
@@ -516,7 +659,7 @@ class SVTrack(BaseModel):
 class SVProject(BaseModel):
     library: list[SVGroup] = Field(default_factory=list)
     render_config: SVRenderConfig = Field(default_factory=SVRenderConfig, alias="renderConfig")
-    instant_mode_enabled: Optional[bool] = Field(False, alias="instantModeEnabled")
+    instant_mode_enabled: bool | None = Field(None, alias="instantModeEnabled")
     time_sig: SVTime = Field(default_factory=SVTime, alias="time")
     tracks: list[SVTrack] = Field(default_factory=list)
-    version: int = 113
+    version: int = 100
