@@ -1,13 +1,11 @@
 import dataclasses
 import sys
 from collections.abc import Callable
-from typing import Optional
+from typing import TYPE_CHECKING
 
-from libresvip.core.constants import TICKS_IN_BEAT
 from libresvip.core.tick_counter import skip_beat_list
 from libresvip.core.time_sync import TimeSynchronizer
 from libresvip.model.base import (
-    InstrumentalTrack,
     Note,
     ParamCurve,
     Params,
@@ -17,32 +15,41 @@ from libresvip.model.base import (
     TimeSignature,
     Track,
 )
-from libresvip.utils import (
-    audio_track_info,
+from libresvip.model.pitch_simulator import PitchSimulator
+from libresvip.model.portamento import PortamentoPitch
+from libresvip.utils.audio import audio_track_info
+from libresvip.utils.music_math import (
     clamp,
-    find_index,
-    find_last_index,
     ratio_to_db,
 )
+from libresvip.utils.search import find_index, find_last_index
 
 from .constants import TICK_RATE
 from .interval_utils import ticks_to_position
 from .model import (
     SVAudio,
+    SVCurvePitchControl,
     SVMeter,
     SVMixer,
     SVNote,
     SVParamCurve,
     SVParameters,
+    SVPhonemeAttribute,
     SVPoint,
     SVProject,
     SVTempo,
     SVTrack,
 )
-from .options import OutputOptions, VibratoOption, synthv_language_presets
+from .options import (
+    OutputOptions,
+    SVProjectVersionCompatibility,
+    VibratoOption,
+    synthv_language_presets,
+)
 from .phoneme_utils import default_phone_marks, number_of_phones, sv_g2p
-from .pitch_simulator import PitchSimulator
-from .pitch_slide import PitchSlide
+
+if TYPE_CHECKING:
+    from libresvip.model.point import Point
 
 
 @dataclasses.dataclass
@@ -58,15 +65,17 @@ class SynthVGenerator:
 
     def generate_project(self, project: Project) -> SVProject:
         sv_project = SVProject()
+        if self.options.version_compatibility == SVProjectVersionCompatibility.BELOW_1_9_0:
+            sv_project.instant_mode_enabled = False
+        elif (
+            self.options.version_compatibility
+            == SVProjectVersionCompatibility.BETWEEN_1_10_0_AND_1_11_2
+        ):
+            sv_project.version = SVProjectVersionCompatibility.BETWEEN_1_10_0_AND_1_11_2.value
+        else:
+            sv_project.version = SVProjectVersionCompatibility.ABOVE_2_0_0.value
         new_meters = skip_beat_list(project.time_signature_list, 1)
-        self.first_bar_tick = int(
-            round(
-                TICKS_IN_BEAT
-                * 4
-                * project.time_signature_list[0].numerator
-                / project.time_signature_list[0].denominator
-            )
-        )
+        self.first_bar_tick = round(project.time_signature_list[0].bar_length())
         self.first_bar_tempo = [
             tempo for tempo in project.song_tempo_list if tempo.position < self.first_bar_tick
         ]
@@ -81,9 +90,9 @@ class SynthVGenerator:
             for meter in new_meters:
                 sv_project.time_sig.meter.append(self.generate_meter(meter))
         for track_id, track in enumerate(project.track_list):
-            sv_track = self.generate_track(track)
-            sv_track.disp_order = track_id
-            sv_project.tracks.append(sv_track)
+            if (sv_track := self.generate_track(track, project.time_signature_list)) is not None:
+                sv_track.disp_order = track_id
+                sv_project.tracks.append(sv_track)
         return sv_project
 
     @staticmethod
@@ -98,7 +107,9 @@ class SynthVGenerator:
             denominator=signature.denominator,
         )
 
-    def generate_track(self, track: Track) -> Optional[SVTrack]:
+    def generate_track(
+        self, track: Track, time_signature_list: list[TimeSignature]
+    ) -> SVTrack | None:
         sv_track = SVTrack(
             name=track.title,
             mixer=SVMixer(
@@ -120,12 +131,19 @@ class SynthVGenerator:
             self.pitch_simulator = PitchSimulator(
                 synchronizer=self.synchronizer,
                 note_list=track.note_list,
-                slide=PitchSlide.sigmoid_slide(),
+                time_signature_list=time_signature_list,
+                portamento=PortamentoPitch.sigmoid_portamento(),
             )
             sv_track.main_group.parameters = self.generate_params(track.edited_params)
+            if self.options.version_compatibility == SVProjectVersionCompatibility.ABOVE_2_0_0:
+                sv_track.main_group.pitch_controls = self.generate_pitch_controls(
+                    track.edited_params.pitch.reduce_sample_rate(
+                        self.options.down_sample, interrupt_value=-100
+                    )
+                )
 
             self.lyrics_phonemes = sv_g2p(
-                (SVNote.normalize_lyric(note) for note in track.note_list),
+                (SVNote.normalize_phoneme(note) for note in track.note_list),
                 [language_preset.language] * len(track.note_list),
             )
 
@@ -137,15 +155,13 @@ class SynthVGenerator:
             elif self.options.vibrato == VibratoOption.HYBRID:
                 for index in self.no_vibrato_indexes:
                     sv_track.main_group.notes[index].attributes.vibrato_depth = 0
-        elif isinstance(track, InstrumentalTrack):
+        else:
             sv_track.main_ref.is_instrumental = True
             sv_track.disp_color = "ff4794cb"
             sv_track.main_ref.audio = SVAudio(filename=track.audio_file_path, duration=0)
             sv_track.main_ref.blick_offset = self.generate_audio_offset(track.offset)
             if (track_info := audio_track_info(track.audio_file_path)) is not None:
                 sv_track.main_ref.audio.duration = track_info.duration / 1000
-        else:
-            return
         return sv_track
 
     def generate_audio_offset(self, offset: int) -> int:
@@ -173,10 +189,7 @@ class SynthVGenerator:
         return max(ratio_to_db(max(volume, 0.06)), -24.0)
 
     def generate_params(self, parameters: Params) -> SVParameters:
-        return SVParameters(
-            pitch_delta=self.generate_pitch_curve(
-                parameters.pitch.reduce_sample_rate(self.options.down_sample, -100)
-            ),
+        sv_params = SVParameters(
             loudness=self.generate_param_curve(
                 parameters.volume.reduce_sample_rate(self.options.down_sample),
                 0,
@@ -184,7 +197,10 @@ class SynthVGenerator:
                 lambda val: (
                     val / 1000.0 * 12.0
                     if val >= 0
-                    else max(ratio_to_db(val / 1000.0 + 1.0 if val > -997 else 0.0039), -48.0)
+                    else max(
+                        ratio_to_db(val / 1000.0 + 1.0 if val > -997 else 0.0039),
+                        -48.0,
+                    )
                 ),
             ),
             tension=self.generate_param_curve(
@@ -200,6 +216,58 @@ class SynthVGenerator:
                 (1000.0).__rtruediv__,
             ),
         )
+        if self.options.version_compatibility != SVProjectVersionCompatibility.ABOVE_2_0_0:
+            sv_params.pitch_delta = self.generate_pitch_curve(
+                parameters.pitch.reduce_sample_rate(self.options.down_sample, -100)
+            )
+        return sv_params
+
+    def generate_pitch_controls(self, curve: ParamCurve) -> list[SVCurvePitchControl]:
+        pitch_controls: list[SVCurvePitchControl] = []
+        buffer: list[Point] = []
+        for point in curve.points.root:
+            if point.x >= self.first_bar_tick:
+                point = point._replace(x=point.x - self.first_bar_tick)
+                if point.y == -100:
+                    if not buffer:
+                        continue
+                    base_positon = ticks_to_position(buffer[0].x)
+                    base_pitch = buffer[0].y
+                    pitch_controls.append(
+                        SVCurvePitchControl(
+                            pos=base_positon,
+                            pitch=base_pitch / 100.0,
+                            id_value=str(len(pitch_controls) + 1),
+                            points=[
+                                SVPoint(
+                                    offset=ticks_to_position(tmp_point.x) - base_positon,
+                                    value=(tmp_point.y - base_pitch) / 100.0,
+                                )
+                                for tmp_point in buffer
+                            ],
+                        )
+                    )
+                    buffer.clear()
+                else:
+                    buffer.append(point)
+        if buffer:
+            base_positon = ticks_to_position(buffer[0].x)
+            base_pitch = buffer[0].y
+            pitch_controls.append(
+                SVCurvePitchControl(
+                    pos=base_positon,
+                    pitch=base_pitch / 100.0,
+                    id_value=str(len(pitch_controls) + 1),
+                    points=[
+                        SVPoint(
+                            offset=ticks_to_position(tmp_point.x) - base_positon,
+                            value=(tmp_point.y - base_pitch) / 100.0,
+                        )
+                        for tmp_point in buffer
+                    ],
+                )
+            )
+        return pitch_controls
 
     def generate_pitch_curve(self, curve: ParamCurve) -> SVParamCurve:
         sv_curve = SVParamCurve()
@@ -208,14 +276,14 @@ class SynthVGenerator:
         if not len(self.note_buffer):
             return sv_curve
         point_list = sv_curve.points
-        buffer = []
+        buffer: list[Point] = []
         min_interval = 1
         last_point = None
         for point in curve.points.root:
             if point.x >= self.first_bar_tick:
                 point = point._replace(x=point.x - self.first_bar_tick)
                 if point.y == -100:
-                    if not len(buffer):
+                    if not buffer:
                         continue
                     if last_point is None or last_point.x + min_interval < buffer[0].x:
                         if last_point is not None and last_point.x + 2 * min_interval < buffer[0].x:
@@ -244,14 +312,20 @@ class SynthVGenerator:
                     buffer.append(point)
         if last_point is not None:
             point_list.append(
-                SVPoint(offset=ticks_to_position(last_point.x + min_interval), value=0)
+                SVPoint(
+                    offset=ticks_to_position(last_point.x + min_interval),
+                    value=0,
+                )
             )
         return sv_curve
 
-    @staticmethod
-    def generate_note(note: Note) -> SVNote:
+    def generate_note(self, note: Note) -> SVNote:
         onset = ticks_to_position(note.start_pos)
         return SVNote(
+            instant_mode=False
+            if self.options.version_compatibility
+            == SVProjectVersionCompatibility.BETWEEN_1_10_0_AND_1_11_2
+            else None,
             onset=onset,
             pitch=note.key_number,
             lyrics=note.lyric or note.pronunciation or "",
@@ -261,9 +335,14 @@ class SynthVGenerator:
     def generate_pitch_diff(self, pos: int, pitch: int) -> float:
         target_note_index = find_last_index(self.note_buffer, lambda x: x.start_pos <= pos)
         target_note = self.note_buffer[target_note_index] if target_note_index >= 0 else None
-        pitch_diff = pitch - self.pitch_simulator.pitch_at_secs(
-            self.synchronizer.get_actual_secs_from_ticks(pos)
-        )
+        if (
+            simulated_pitch := self.pitch_simulator.pitch_at_secs(
+                self.synchronizer.get_actual_secs_from_ticks(pos)
+            )
+        ) is not None:
+            pitch_diff = pitch - simulated_pitch
+        else:
+            pitch_diff = 0.0
         if target_note is None:
             return pitch_diff
         if (
@@ -313,14 +392,14 @@ class SynthVGenerator:
                         value=mapping_func(y0),
                     )
                 )
-        buffer = []
+        buffer: list[Point] = []
         min_interval = 1
         last_point = None
         for point in curve.points.root[skipped:]:
             if self.first_bar_tick <= point.x < sys.maxsize // 2:
                 point = point._replace(x=point.x - self.first_bar_tick)
                 if point.y == termination:
-                    if not len(buffer):
+                    if not buffer:
                         continue
                     if last_point is None or last_point.x + min_interval < buffer[0].x:
                         if last_point is not None and last_point.x + 2 * min_interval < buffer[0].x:
@@ -348,7 +427,7 @@ class SynthVGenerator:
                 else:
                     buffer.append(point)
 
-        if not len(buffer):
+        if not buffer:
             if last_point is not None:
                 point_list.append(
                     SVPoint(
@@ -390,26 +469,32 @@ class SynthVGenerator:
         return sv_curve
 
     def generate_notes_with_phones(self, notes: list[Note]) -> list[SVNote]:
-        sv_note_list = []
+        sv_note_list: list[SVNote] = []
         if not len(notes):
             return sv_note_list
         current_note = notes[0]
         current_sv_note = self.generate_note(current_note)
         current_phone_marks = default_phone_marks(
-            self.lyrics_phonemes[0], self.options.language_override
+            self.lyrics_phonemes[0], self.options.language_override.value
         )
         if (
-            current_phone_marks[0] > 0
-            and notes[0].edited_phones is not None
-            and notes[0].edited_phones.head_length_in_secs > 0
+            current_note.edited_phones is not None
+            and current_note.edited_phones.head_length_in_secs > 0
         ):
-            ratio = notes[0].edited_phones.head_length_in_secs / current_phone_marks[0]
-            current_sv_note.attributes.set_phone_duration(0, clamp(ratio, 0.2, 1.8))
+            if self.options.version_compatibility == SVProjectVersionCompatibility.ABOVE_2_0_0:
+                current_sv_note.attributes.phonemes = [
+                    SVPhonemeAttribute(left_offset=-current_note.edited_phones.head_length_in_secs)
+                ]
+            elif current_phone_marks[0] > 0:
+                ratio = current_note.edited_phones.head_length_in_secs / current_phone_marks[0]
+                current_sv_note.attributes.set_phone_duration(0, clamp(ratio, 0.2, 1.8))
         for next_note, cur_phoneme, next_phoneme in zip(
             notes[1:], self.lyrics_phonemes[:-1], self.lyrics_phonemes[1:]
         ):
             next_sv_note = self.generate_note(next_note)
-            next_phone_marks = default_phone_marks(next_phoneme, self.options.language_override)
+            next_phone_marks = default_phone_marks(
+                next_phoneme, self.options.language_override.value
+            )
 
             current_main_part_edited = (
                 current_phone_marks[1] > 0
@@ -423,7 +508,19 @@ class SynthVGenerator:
             )
 
             index = 1 if current_phone_marks[0] > 0 else 0
-            if current_main_part_edited and next_head_part_edited:
+            if (
+                next_note.edited_phones is not None
+                and next_note.edited_phones.head_length_in_secs > 0
+            ):
+                next_sv_note.attributes.phonemes = [
+                    SVPhonemeAttribute(left_offset=-next_note.edited_phones.head_length_in_secs)
+                ]
+            elif (
+                current_main_part_edited
+                and next_head_part_edited
+                and (current_note.edited_phones is not None)
+                and (next_note.edited_phones is not None)
+            ):
                 current_main_ratio = (
                     current_note.edited_phones.mid_ratio_over_tail / current_phone_marks[1]
                 )
@@ -444,13 +541,13 @@ class SynthVGenerator:
                 current_sv_note.attributes.set_phone_duration(index, clamp(x, 0.2, 1.8))
                 current_sv_note.attributes.set_phone_duration(index + 1, clamp(y, 0.2, 1.8))
                 next_sv_note.attributes.set_phone_duration(0, clamp(z, 0.2, 1.8))
-            elif current_main_part_edited:
+            elif current_main_part_edited and current_note.edited_phones is not None:
                 ratio = current_note.edited_phones.mid_ratio_over_tail / current_phone_marks[1]
                 x = 2 * ratio / (1 + ratio)
                 y = 2 / (1 + ratio)
                 current_sv_note.attributes.set_phone_duration(index, clamp(x, 0.2, 1.8))
                 current_sv_note.attributes.set_phone_duration(index + 1, clamp(y, 0.2, 1.8))
-            elif next_head_part_edited:
+            elif next_head_part_edited and next_note.edited_phones is not None:
                 ratio = next_note.edited_phones.head_length_in_secs / next_phone_marks[0]
                 if (
                     self.synchronizer.get_duration_secs_from_ticks(
@@ -468,7 +565,9 @@ class SynthVGenerator:
                     ratio = ratio_z
                 next_sv_note.attributes.set_phone_duration(0, ratio)
             if current_sv_note.attributes.dur is not None:
-                expected_length = number_of_phones(cur_phoneme, self.options.language_override)
+                expected_length = number_of_phones(
+                    cur_phoneme, self.options.language_override.value
+                )
                 if len(current_sv_note.attributes.dur) < expected_length:
                     current_sv_note.attributes.set_phone_duration(expected_length - 1, 1.0)
 
@@ -481,6 +580,7 @@ class SynthVGenerator:
             current_phone_marks[1] > 0
             and current_note.edited_phones is not None
             and current_note.edited_phones.mid_ratio_over_tail > 0
+            and notes[-1].edited_phones is not None
         ):
             ratio = notes[-1].edited_phones.mid_ratio_over_tail / current_phone_marks[1]
             x = 2 * ratio / (1 + ratio)
@@ -490,7 +590,7 @@ class SynthVGenerator:
             current_sv_note.attributes.set_phone_duration(index + 1, clamp(y, 0.2, 1.8))
         if current_sv_note.attributes.dur is not None:
             expected_length = number_of_phones(
-                self.lyrics_phonemes[-1], self.options.language_override
+                self.lyrics_phonemes[-1], self.options.language_override.value
             )
             if len(current_sv_note.attributes.dur) < expected_length:
                 current_sv_note.attributes.set_phone_duration(expected_length - 1, 1.0)
