@@ -1,11 +1,15 @@
 import dataclasses
+import operator
 import re
 from collections.abc import Callable
 from functools import partial, reduce
-from typing import Optional
+from typing import cast
+
+import more_itertools
 
 from libresvip.core.constants import DEFAULT_BPM
-from libresvip.core.tick_counter import shift_beat_list, shift_tempo_list
+from libresvip.core.exceptions import NotesOverlappedError
+from libresvip.core.tick_counter import find_bar_index, shift_beat_list, shift_tempo_list
 from libresvip.core.time_interval import RangeInterval
 from libresvip.core.time_sync import TimeSynchronizer
 from libresvip.model.base import (
@@ -21,9 +25,17 @@ from libresvip.model.base import (
     Track,
 )
 from libresvip.model.point import Point
-from libresvip.utils import clamp, db_to_float, find_index, ratio_to_db
+from libresvip.utils.music_math import (
+    clamp,
+    cosine_easing_in_out_interpolation,
+    cubic_interpolation,
+    db_to_float,
+    linear_interpolation,
+    ratio_to_db,
+)
+from libresvip.utils.search import find_index
+from libresvip.utils.translation import gettext_lazy as _
 
-from . import interpolation
 from .constants import TICK_RATE
 from .interval_utils import position_to_ticks
 from .model import (
@@ -33,17 +45,18 @@ from .model import (
     SVNote,
     SVParamCurve,
     SVParameters,
+    SVPitchControl,
     SVProject,
     SVTempo,
     SVTrack,
     SVVoice,
 )
 from .options import BreathOption, GroupOption, InputOptions, PitchOption
-from .param_expression import CompoundParam, CurveGenerator, PitchGenerator
+from .param_expression import CurveGenerator, ParamExpression, PitchGenerator
 from .phoneme_utils import default_phone_marks, sv_g2p, xsampa2pinyin
 from .track_merge_utils import track_override_with
 
-clip = partial(clamp, lower=-1000, upper=1000)
+clip = cast("Callable[[int], int]", partial(clamp, lower=-1000, upper=1000))
 
 
 @dataclasses.dataclass
@@ -54,27 +67,29 @@ class SynthVParser:
     synchronizer: TimeSynchronizer = dataclasses.field(init=False)
     voice_settings: SVVoice = dataclasses.field(init=False)
     instant_pitch: SVParamCurve = dataclasses.field(init=False)
-    note_list: list[SVNote] = dataclasses.field(init=False)
     group_library: dict[str, SVGroup] = dataclasses.field(default_factory=dict)
     group_split_counts: dict[str, int] = dataclasses.field(default_factory=dict)
     tracks_from_groups: list[Track] = dataclasses.field(default_factory=list)
+    time_signatures: list[TimeSignature] = dataclasses.field(default_factory=list)
 
     def actual_value_at(
         self,
-        compound_expr: CompoundParam,
+        compound_expr: ParamExpression,
         mapping_func: Callable[[float], int],
         ticks: int,
     ) -> int:
         return clip(mapping_func(compound_expr.value_at_ticks(ticks) / 1000))
 
     @staticmethod
-    def parse_interpolation(mode: str) -> Callable[[float], float]:
+    def parse_interpolation(
+        mode: str,
+    ) -> Callable[[float, tuple[float, float], tuple[float, float]], float]:
         if mode == "cosine":
-            return interpolation.cosine_interpolation
+            return cosine_easing_in_out_interpolation
         elif mode == "cubic":
-            return interpolation.cubic_interpolation
+            return cubic_interpolation
         else:
-            return interpolation.linear_interpolation
+            return linear_interpolation
 
     def parse_audio_offset(self, offset: int) -> int:
         if offset >= 0:
@@ -104,8 +119,8 @@ class SynthVParser:
         self,
         sv_curve: SVParamCurve,
         mapping_func: Callable[[float], int],
-        base_value: float = 0.0,
-        master_curve: Optional[SVParamCurve] = None,
+        base_value: float | None = None,
+        master_curve: SVParamCurve | None = None,
     ) -> ParamCurve:
         if base_value is None:
             base_value = 0.0
@@ -165,6 +180,7 @@ class SynthVParser:
                 for point in master_curve.points.root
             ],
             _interpolation=self.parse_interpolation(master_curve.mode),
+            _base_value=0,
         )
         compound_expr = group_expr + master_expr
         group_points = group_expr.point_list
@@ -214,7 +230,10 @@ class SynthVParser:
             else:
                 for p in range(prev_point.x, current_point.x, 5):
                     curve.points.append(
-                        Point(p, self.actual_value_at(compound_expr, mapping_func, p))
+                        Point(
+                            p,
+                            self.actual_value_at(compound_expr, mapping_func, p),
+                        )
                     )
             prev_point = current_point
             prev_point_is_base = current_point_is_base
@@ -235,16 +254,18 @@ class SynthVParser:
         self,
         pitch_diff: SVParamCurve,
         vibrato_env: SVParamCurve,
+        sv_notes: list[SVNote],
         step: int = 5,
-        master_pitch_diff: Optional[SVParamCurve] = None,
-        master_vibrato_env: Optional[SVParamCurve] = None,
+        master_pitch_diff: SVParamCurve | None = None,
+        master_vibrato_env: SVParamCurve | None = None,
+        pitch_controls: list[SVPitchControl] | None = None,
     ) -> ParamCurve:
         curve = ParamCurve()
-        if not len(self.note_list):
+        if not sv_notes:
             curve.points.append(Point.start_point())
             curve.points.append(Point.end_point())
             return curve
-        pitch_diff_expr = CurveGenerator(
+        pitch_diff_expr: ParamExpression = CurveGenerator(
             _point_list=[
                 Point(
                     position_to_ticks(point.offset),
@@ -253,8 +274,9 @@ class SynthVParser:
                 for point in pitch_diff.points.root
             ],
             _interpolation=self.parse_interpolation(pitch_diff.mode),
+            _base_value=0,
         )
-        vibrato_env_expr = CurveGenerator(
+        vibrato_env_expr: ParamExpression = CurveGenerator(
             _point_list=[
                 Point(
                     position_to_ticks(point.offset),
@@ -275,6 +297,7 @@ class SynthVParser:
                     for point in master_pitch_diff.points.root
                 ],
                 _interpolation=self.parse_interpolation(master_pitch_diff.mode),
+                _base_value=0,
             )
         if master_vibrato_env is not None:
             vibrato_env_expr += CurveGenerator(
@@ -286,9 +309,21 @@ class SynthVParser:
                     for point in master_vibrato_env.points.root
                 ],
                 _interpolation=self.parse_interpolation(vibrato_env.mode),
+                _base_value=0,
             )
         if self.options.instant:
+            instant_interval = RangeInterval(
+                [
+                    (
+                        position_to_ticks(note.onset),
+                        position_to_ticks(note.onset + note.duration),
+                    )
+                    for note in sv_notes
+                    if note.instant_mode is not False
+                ]
+            )
             pitch_diff_expr += CurveGenerator(
+                interval=instant_interval.interval,
                 _point_list=[
                     Point(
                         position_to_ticks(point.offset),
@@ -297,6 +332,7 @@ class SynthVParser:
                     for point in self.instant_pitch.points.root
                 ],
                 _interpolation=self.parse_interpolation(self.instant_pitch.mode),
+                _base_value=0,
             )
         interval = RangeInterval(
             [
@@ -304,10 +340,17 @@ class SynthVParser:
                     position_to_ticks(note.onset),
                     position_to_ticks(note.onset + note.duration),
                 )
-                for note in self.note_list
+                for note in sv_notes
             ]
         ).expand(120)
 
+        generator = PitchGenerator(
+            _synchronizer=self.synchronizer,
+            _note_list=sv_notes,
+            _pitch_diff=pitch_diff_expr,
+            _vibrato_env=vibrato_env_expr,
+            _pitch_controls=pitch_controls,
+        )
         if self.options.pitch in {PitchOption.VIBRATO, PitchOption.PLAIN}:
             regard_default_vibrato_as_unedited = self.options.pitch == PitchOption.PLAIN
             pitch_interval = 0.1
@@ -339,82 +382,100 @@ class SynthVParser:
                 reduced_interval,
                 (
                     note
-                    for note in self.note_list
-                    if note.pitch_edited(regard_default_vibrato_as_unedited, self.options.instant)
+                    for note in sv_notes
+                    if note.pitch_edited(
+                        regard_default_vibrato_as_unedited,
+                        self.options.instant,
+                    )
                 ),
                 RangeInterval(),
             )
             param_edited_range = pitch_diff.edited_range() | vibrato_env.edited_range(1.0)
             if master_pitch_diff is not None:
                 param_edited_range |= master_pitch_diff.edited_range()
+            if generator.pitch_control_layer is not None:
+                param_edited_range.interval |= generator.pitch_control_layer.interval_dict.domain()
             if master_vibrato_env is not None:
                 param_edited_range |= master_vibrato_env.edited_range(1.0)
             interval &= note_edited_range | param_edited_range
-        generator = PitchGenerator(
-            _synchronizer=self.synchronizer,
-            _note_list=self.note_list,
-            _pitch_diff=pitch_diff_expr,
-            _vibrato_env=vibrato_env_expr,
-        )
         curve.points.append(Point.start_point())
         for start, end in interval.shift(self.first_bar_tick).sub_ranges():
             curve.points.append(Point(start, -100))
             curve.points.extend(
-                Point(i, generator.value_at_ticks(i - self.first_bar_tick))
+                Point(i, round(generator.value_at_ticks(i - self.first_bar_tick)))
                 for i in range(start, end, step)
             )
-            curve.points.append(Point(end, generator.value_at_ticks(end - self.first_bar_tick)))
+            curve.points.append(
+                Point(
+                    end,
+                    round(generator.value_at_ticks(end - self.first_bar_tick)),
+                )
+            )
             curve.points.append(Point(end, -100))
         curve.points.append(Point.end_point())
         return curve
 
     def parse_params(
-        self, sv_params: SVParameters, master_params: Optional[SVParameters] = None
+        self,
+        sv_params: SVParameters,
+        sv_notes: list[SVNote],
+        master_params: SVParameters | None = None,
+        pitch_controls: list[SVPitchControl] | None = None,
     ) -> Params:
-        return Params(
-            pitch=self.parse_pitch_curve(
+        params = Params()
+        if self.options.import_pitch:
+            params.pitch = self.parse_pitch_curve(
                 sv_params.pitch_delta,
                 sv_params.vibrato_env,
+                sv_notes,
                 5,
                 master_params.pitch_delta if master_params else None,
                 master_params.vibrato_env if master_params else None,
-            ),
-            volume=self.parse_param_curve(
+                pitch_controls or None,
+            )
+        if self.options.import_volume:
+            params.volume = self.parse_param_curve(
                 sv_params.loudness,
                 lambda val: round(val / 12.0 * 1000.0)
                 if val >= 0.0
                 else round(1000 * db_to_float(val) - 1000),
-                self.voice_settings.param_loudness,
+                self.voice_settings.param_loudness or 0.0,
                 master_params.loudness if master_params else None,
-            ),
-            breath=self.parse_param_curve(
+            )
+        if self.options.import_breath:
+            params.breath = self.parse_param_curve(
                 sv_params.breathiness,
                 lambda val: round(val * 1000),
-                self.voice_settings.param_breathiness,
+                self.voice_settings.param_breathiness or 0.0,
                 master_params.breathiness if master_params else None,
-            ),
-            gender=self.parse_param_curve(
+            )
+        if self.options.import_gender:
+            params.gender = self.parse_param_curve(
                 sv_params.gender,
                 lambda val: round(val * -1000),
-                self.voice_settings.param_gender,
+                self.voice_settings.param_gender or 0.0,
                 master_params.gender if master_params else None,
-            ),
-            strength=self.parse_param_curve(
+            )
+        if self.options.import_strength:
+            params.strength = self.parse_param_curve(
                 sv_params.tension,
                 lambda val: round(val * 1000),
-                self.voice_settings.param_tension,
+                self.voice_settings.param_tension or 0.0,
                 master_params.tension if master_params else None,
-            ),
-        )
+            )
+        return params
 
     @staticmethod
     def parse_note(sv_note: SVNote, database: SVDatabase) -> Note:
-        note = Note(start_pos=position_to_ticks(sv_note.onset), key_number=sv_note.pitch)
+        note = Note(
+            start_pos=position_to_ticks(sv_note.onset),
+            key_number=sv_note.pitch,
+        )
         note.length = position_to_ticks(sv_note.onset + sv_note.duration) - note.start_pos
-        note.lyric = sv_note.lyrics
+        note.lyric = SVNote.normalize_lyric(sv_note.lyrics)
         if sv_note.phonemes:
             note_default_language = sv_note.attributes.default_language(database)
-            if note_default_language == "japanese":
+            if note_default_language in ["japanese", "korean"]:
                 note.pronunciation = sv_note.phonemes
             elif note_default_language in ["mandarin", "cantonese"]:
                 note.pronunciation = xsampa2pinyin(sv_note.phonemes, note_default_language)
@@ -457,22 +518,41 @@ class SynthVParser:
         if len(sv_note_list):
             lyrics, languages = zip(
                 *(
-                    (SVNote.normalize_lyric(note), sv_note.attributes.default_language(database))
+                    (
+                        SVNote.normalize_phoneme(note),
+                        sv_note.attributes.default_language(database),
+                    )
                     for note, sv_note in zip(note_list, sv_note_list)
                 )
             )
         else:
-            lyrics, languages = [], []
+            lyrics, languages = (), ()
         lyrics_phoneme = sv_g2p(lyrics, languages)
         if not len(note_list):
             return note_list
+        for prev_note, note in more_itertools.pairwise(note_list):
+            if prev_note.end_pos > note.start_pos:
+                msg = _("Notes overlapped near bar {}").format(
+                    find_bar_index(self.time_signatures, note.start_pos)
+                )
+                raise NotesOverlappedError(msg)
         current_sv_note = sv_note_list[0]
         current_duration = current_sv_note.attributes.dur
+        current_phonemes = current_sv_note.attributes.phonemes
         current_phone_marks = default_phone_marks(
-            lyrics_phoneme[0], current_sv_note.attributes.default_language(database)
+            lyrics_phoneme[0],
+            current_sv_note.attributes.default_language(database),
         )
 
         if (
+            current_phonemes is not None
+            and len(current_phonemes) > 0
+            and current_phonemes[0].left_offset is not None
+        ):
+            note_list[0].edited_phones = Phones(
+                head_length_in_secs=min(1.8, -current_phonemes[0].left_offset),
+            )
+        elif (
             current_phone_marks[0] > 0
             and current_duration is not None
             and current_duration[0] != 1.0
@@ -484,26 +564,34 @@ class SynthVParser:
         for i in range(len(sv_note_list) - 1):
             next_sv_note = sv_note_list[i + 1]
             next_duration = next_sv_note.attributes.dur
+            next_phonemes = next_sv_note.attributes.phonemes
             next_phone_marks = default_phone_marks(
-                lyrics_phoneme[i + 1], next_sv_note.attributes.default_language(database)
+                lyrics_phoneme[i + 1],
+                next_sv_note.attributes.default_language(database),
             )
 
             index = 1 if next_phone_marks[0] > 0 else 0
-            current_main_part_edited = (
+            if (
+                next_phonemes is not None
+                and len(next_phonemes)
+                and next_phonemes[0].left_offset is not None
+            ):
+                next_head_part_length = -next_phonemes[0].left_offset
+            elif next_phone_marks[0] > 0 and next_duration is not None and len(next_duration):
+                next_head_part_length = next_duration[0] * next_phone_marks[0]
+            else:
+                next_head_part_length = None
+            if (
                 current_phone_marks[1] > 0
                 and current_duration is not None
-                and len(current_duration) > index
-            )
-            next_head_part_edited = (
-                next_phone_marks[0] > 0 and next_duration is not None and len(next_duration)
-            )
-            if current_main_part_edited and len(current_duration) > index + 1:
+                and len(current_duration) > index + 1
+            ):
                 if note_list[i].edited_phones is None:
                     note_list[i].edited_phones = Phones()
-                note_list[i].edited_phones.mid_ratio_over_tail = (
+                note_list[i].edited_phones.mid_ratio_over_tail = (  #  type: ignore[union-attr]
                     current_phone_marks[1] * current_duration[index] / current_duration[index + 1]
                 )
-            if next_head_part_edited:
+            if next_head_part_length is not None:
                 if note_list[i + 1].edited_phones is None:
                     note_list[i + 1].edited_phones = Phones()
                 space_in_secs = min(
@@ -513,48 +601,58 @@ class SynthVParser:
                         note_list[i + 1].start_pos + self.first_bar_tick,
                     ),
                 )
-                length = next_phone_marks[0] * next_duration[0]
-                if current_main_part_edited:
+                if (
+                    current_phone_marks[1] > 0
+                    and current_duration is not None
+                    and len(current_duration) > index
+                ):
                     ratio = (
                         2 / (current_duration[index] + current_duration[index + 1])
                         if len(current_duration) > index + 1
                         else 1 / current_duration[index]
                     )
-                    if length * ratio > self.synchronizer.get_duration_secs_from_ticks(
-                        note_list[i].end_pos + self.first_bar_tick,
-                        note_list[i + 1].start_pos + self.first_bar_tick,
+                    if (
+                        next_head_part_length * ratio
+                        > self.synchronizer.get_duration_secs_from_ticks(
+                            note_list[i].end_pos + self.first_bar_tick,
+                            note_list[i + 1].start_pos + self.first_bar_tick,
+                        )
                     ):
-                        length *= ratio
-                note_list[i + 1].edited_phones.head_length_in_secs = min(
-                    0.9 * space_in_secs, length
+                        next_head_part_length *= ratio
+                note_list[i + 1].edited_phones.head_length_in_secs = min(  #  type: ignore[union-attr]
+                    0.9 * space_in_secs, next_head_part_length
                 )
             current_duration = next_duration
             current_phone_marks = next_phone_marks
-        idx = 1 if current_phone_marks[0] > 0 else 0
+        index = 1 if current_phone_marks[0] > 0 else 0
         if (
             current_phone_marks[1] > 0
             and current_duration is not None
-            and len(current_duration) > idx + 1
+            and len(current_duration) > index + 1
         ):
             if note_list[-1].edited_phones is None:
                 note_list[-1].edited_phones = Phones()
             note_list[-1].edited_phones.mid_ratio_over_tail = (
-                current_phone_marks[1] * current_duration[idx] / current_duration[idx + 1]
+                current_phone_marks[1] * current_duration[index] / current_duration[index + 1]
             )
         return note_list
 
-    def parse_track(self, sv_track: SVTrack) -> Track:
+    def parse_track(self, sv_track: SVTrack) -> Track | None:
         if sv_track.main_ref.is_instrumental:
-            svip_track = InstrumentalTrack(
-                audio_file_path=sv_track.main_ref.audio.filename,
-                offset=self.parse_audio_offset(sv_track.main_ref.blick_offset),
-            )
+            if self.options.import_instrumental_track and sv_track.main_ref.audio is not None:
+                svip_track = InstrumentalTrack(
+                    audio_file_path=sv_track.main_ref.audio.filename,
+                    offset=self.parse_audio_offset(sv_track.main_ref.blick_offset),
+                )
+            else:
+                return None
         else:
             self.voice_settings = sv_track.main_ref.voice
             master_note_attributes = self.voice_settings.to_attributes()
             if self.options.instant:
-                self.instant_pitch = sv_track.main_ref.system_pitch_delta
-            self.note_list = sv_track.main_group.notes
+                self.instant_pitch = (
+                    sv_track.main_ref.system_pitch_delta + sv_track.main_ref.blick_offset
+                )
             for note in sv_track.main_group.notes:
                 note.merge_attributes(master_note_attributes)
             singing_track = SingingTrack(
@@ -562,7 +660,9 @@ class SynthVParser:
                 note_list=self.parse_note_list(
                     sv_track.main_group.notes, sv_track.main_ref.database
                 ),
-                edited_params=self.parse_params(sv_track.main_group.parameters),
+                edited_params=self.parse_params(
+                    sv_track.main_group.parameters, sv_track.main_group.notes
+                ),
             )
             if self.options.group == GroupOption.SPLIT:
                 for sv_ref in sv_track.groups:
@@ -573,7 +673,7 @@ class SynthVParser:
                     voice_settings = sv_ref.voice
                     master_note_attributes = voice_settings.to_attributes()
                     if self.options.instant:
-                        self.instant_pitch = sv_ref.system_pitch_delta
+                        self.instant_pitch = sv_ref.system_pitch_delta + sv_ref.blick_offset
                     for note in group.notes:
                         note.merge_attributes(master_note_attributes)
                     self.group_split_counts[sv_ref.group_id] += 1
@@ -583,7 +683,10 @@ class SynthVParser:
                             title=f"{group.name} ({self.group_split_counts[sv_ref.group_id]})",
                             note_list=self.parse_note_list(group.notes, sv_ref.database),
                             edited_params=self.parse_params(
-                                group.parameters, sv_track.main_group.parameters
+                                group.parameters,
+                                group.notes,
+                                sv_track.main_group.parameters,
+                                group.pitch_controls,
                             ),
                         )
                     )
@@ -597,7 +700,7 @@ class SynthVParser:
                     voice_settings = sv_ref.voice
                     master_note_attributes = voice_settings.to_attributes()
                     if self.options.instant:
-                        self.instant_pitch = sv_ref.system_pitch_delta
+                        self.instant_pitch = sv_ref.system_pitch_delta + sv_ref.blick_offset
                     for note in group.notes:
                         note.merge_attributes(master_note_attributes)
                     if merged_group.overlapped_with(group):
@@ -608,19 +711,27 @@ class SynthVParser:
                                 title=f"{group.name} ({self.group_split_counts[sv_ref.group_id]})",
                                 note_list=self.parse_note_list(group.notes, sv_ref.database),
                                 edited_params=self.parse_params(
-                                    group.parameters, sv_track.main_group.parameters
+                                    group.parameters,
+                                    group.notes,
+                                    sv_track.main_group.parameters,
+                                    group.pitch_controls,
                                 ),
                             )
                         )
                     else:
                         track_override_with(
                             singing_track,
-                            self.parse_note_list(group.notes),
-                            self.parse_params(group.parameters, sv_track.main_group.parameters),
+                            self.parse_note_list(group.notes, sv_ref.database),
+                            self.parse_params(
+                                group.parameters,
+                                group.notes,
+                                sv_track.main_group.parameters,
+                                group.pitch_controls,
+                            ),
                             self.first_bar_tick,
                         )
                         merged_group.notes.extend(group.notes)
-                        merged_group.notes.sort(key=lambda n: n.onset)
+                        merged_group.notes.sort(key=operator.attrgetter("onset"))
             svip_track = singing_track
         svip_track.title = sv_track.name
         svip_track.mute = sv_track.mixer.mute
@@ -632,15 +743,16 @@ class SynthVParser:
     def parse_project(self, sv_project: SVProject) -> Project:
         project = Project()
         time_sig = sv_project.time_sig
-        self.first_bar_tick = 1920 * time_sig.meter[0].numerator // time_sig.meter[0].denominator
         self.first_bpm = time_sig.tempo[0].bpm
 
-        project.song_tempo_list = shift_tempo_list(
-            [self.parse_tempo(tempo) for tempo in time_sig.tempo], self.first_bar_tick
-        )
-        project.time_signature_list = shift_beat_list(
+        self.time_signatures = project.time_signature_list = shift_beat_list(
             [self.parse_meter(meter) for meter in time_sig.meter], 1
         )
+        self.first_bar_tick = round(project.time_signature_list[0].bar_length())
+        project.song_tempo_list = shift_tempo_list(
+            [self.parse_tempo(tempo) for tempo in time_sig.tempo],
+            self.first_bar_tick,
+        )
         self.synchronizer = TimeSynchronizer(project.song_tempo_list)
 
         for sv_group in sv_project.library:
@@ -648,7 +760,8 @@ class SynthVParser:
             self.group_split_counts[sv_group.uuid] = 0
 
         for sv_track in sv_project.tracks:
-            project.track_list.append(self.parse_track(sv_track))
+            if track := self.parse_track(sv_track):
+                project.track_list.append(track)
 
         project.track_list.extend(self.tracks_from_groups)
         return project
