@@ -5,23 +5,22 @@ from libresvip.extension import base as plugin_base
 from libresvip.model.base import Project
 
 from .model import SVProject
-from .options import InputOptions, OutputOptions
+from .options import InputOptions, OutputOptions, SVProjectVersionCompatibility
 from .synthv_generator import SynthVGenerator
 from .synthv_parser import SynthVParser
 
 
 class SynthVStudioConverter(plugin_base.SVSConverterBase):
     def load(self, path: pathlib.Path, options: InputOptions) -> Project:
-        if options is None:
-            options = InputOptions()
-        sv_content = path.read_text(encoding="utf-8").strip("\x00")
-        sv_proj = SVProject.model_validate_json(sv_content)
-        options.instant = options.instant and sv_proj.instant_mode_enabled
+        sv_content = (
+            path.read_bytes().removesuffix(b"\x00").removeprefix("\ufeff".encode()).decode("utf-8")
+        )
+        sv_proj = SVProject.model_validate_json(sv_content, context={"path": path})
+        if options.instant and sv_proj.instant_mode_enabled is not None:
+            options.instant = sv_proj.instant_mode_enabled
         return SynthVParser(options=options).parse_project(sv_proj)
 
     def dump(self, path: pathlib.Path, project: Project, options: OutputOptions) -> None:
-        if options is None:
-            options = OutputOptions()
         sv_project = SynthVGenerator(
             options=options,
         ).generate_project(project)
@@ -29,6 +28,10 @@ class SynthVStudioConverter(plugin_base.SVSConverterBase):
             json.dumps(
                 sv_project.model_dump(mode="json", by_alias=True, exclude_none=True),
                 separators=(",", ":"),
-            ).encode()
-            + b"\x00"
+            ).encode("utf-8")
+            + (
+                b""
+                if options.version_compatibility == SVProjectVersionCompatibility.ABOVE_2_0_0
+                else b"\x00"
+            )
         )
