@@ -1,5 +1,5 @@
-from libresvip.model.point import (
-    Point,
+from libresvip.model.point import Point
+from libresvip.utils.music_math import (
     interpolate_cosine_ease_in,
     interpolate_cosine_ease_in_out,
     interpolate_cosine_ease_out,
@@ -17,11 +17,10 @@ def interpolate(
 ) -> list[Point]:
     input_data = [last_point, this_point]
     if curve_type == "s":
-        output = interpolate_linear(input_data, sampling_interval_tick)
+        return interpolate_linear(input_data, sampling_interval_tick)
     elif curve_type == "j":
-        output = interpolate_cosine_ease_in(input_data, sampling_interval_tick)
+        return interpolate_cosine_ease_in(input_data, sampling_interval_tick)
     elif curve_type == "r":
-        output = interpolate_cosine_ease_out(input_data, sampling_interval_tick)
+        return interpolate_cosine_ease_out(input_data, sampling_interval_tick)
     else:
-        output = interpolate_cosine_ease_in_out(input_data, sampling_interval_tick)
-    return output
+        return interpolate_cosine_ease_in_out(input_data, sampling_interval_tick)
