@@ -2,9 +2,8 @@ import pathlib
 
 from libresvip.extension import base as plugin_base
 from libresvip.model.base import Project
-from libresvip.utils import to_unicode
 
-from .model import UstVisitor, ust_grammar
+from .model import UstWalker, get_ust_grammar
 from .options import InputOptions, OutputOptions
 from .template import render_ust
 from .ust_generator import USTGenerator
@@ -13,8 +12,10 @@ from .ust_parser import USTParser
 
 class USTConverter(plugin_base.SVSConverterBase):
     def load(self, path: pathlib.Path, options: InputOptions) -> Project:
-        tree = ust_grammar.parse(to_unicode(path.read_bytes()))
-        ust_project = UstVisitor().visit(tree)
+        ust_content = path.read_bytes()
+        ust_text = ust_content.decode(options.encoding, errors="replace")
+        tree = get_ust_grammar().parse(ust_text)
+        ust_project = UstWalker().walk(tree)
         return USTParser(options).parse_project(ust_project)
 
     def dump(self, path: pathlib.Path, project: Project, options: OutputOptions) -> None:
