@@ -1,8 +1,11 @@
-from dataclasses import dataclass, field
 from enum import Enum
 from typing import Optional
 
-from ..enums import VocaloidLanguage
+from xsdata_pydantic.fields import field
+
+from libresvip.model.base import BaseModel
+
+from .enums import VocaloidLanguage
 
 VSQ3_NS = "http://www.yamaha.co.jp/vocaloid/schema/vsq3/"
 
@@ -18,13 +21,12 @@ class ParameterNames(Enum):
     PIT = "PIT"
 
 
-@dataclass
-class Aux:
+class Aux(BaseModel):
     class Meta:
         name = "aux"
         namespace = VSQ3_NS
 
-    aux_id: Optional[str] = field(
+    aux_id: str | None = field(
         default=None,
         metadata={
             "name": "auxID",
@@ -32,7 +34,7 @@ class Aux:
             "required": True,
         },
     )
-    content: Optional[str] = field(
+    content: str | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -41,13 +43,12 @@ class Aux:
     )
 
 
-@dataclass
-class Dyn:
+class Dyn(BaseModel):
     class Meta:
         name = "dyn"
         namespace = VSQ3_NS
 
-    pos_sec: Optional[int] = field(
+    pos_sec: int | None = field(
         default=None,
         metadata={
             "name": "posSec",
@@ -55,7 +56,7 @@ class Dyn:
             "required": True,
         },
     )
-    dyn_val: Optional[int] = field(
+    dyn_val: int | None = field(
         default=None,
         metadata={
             "name": "dynVal",
@@ -65,13 +66,12 @@ class Dyn:
     )
 
 
-@dataclass
-class Pch:
+class Pch(BaseModel):
     class Meta:
         name = "pch"
         namespace = VSQ3_NS
 
-    pos_sec: Optional[int] = field(
+    pos_sec: int | None = field(
         default=None,
         metadata={
             "name": "posSec",
@@ -79,7 +79,7 @@ class Pch:
             "required": True,
         },
     )
-    pch_val: Optional[int] = field(
+    pch_val: int | None = field(
         default=None,
         metadata={
             "name": "pchVal",
@@ -89,13 +89,12 @@ class Pch:
     )
 
 
-@dataclass
-class Phnm:
+class Phnm(BaseModel):
     class Meta:
         name = "phnm"
         namespace = VSQ3_NS
 
-    pos_sec: Optional[int] = field(
+    pos_sec: int | None = field(
         default=None,
         metadata={
             "name": "posSec",
@@ -103,7 +102,7 @@ class Phnm:
             "required": True,
         },
     )
-    dur_sec: Optional[int] = field(
+    dur_sec: int | None = field(
         default=None,
         metadata={
             "name": "durSec",
@@ -111,7 +110,7 @@ class Phnm:
             "required": True,
         },
     )
-    phnm_str: Optional[str] = field(
+    phnm_str: str | None = field(
         default=None,
         metadata={
             "name": "phnmStr",
@@ -121,8 +120,7 @@ class Phnm:
     )
 
 
-@dataclass
-class SeqAttr:
+class SeqAttr(BaseModel):
     class Meta:
         name = "seqAttr"
         namespace = VSQ3_NS
@@ -134,7 +132,7 @@ class SeqAttr:
             "min_occurs": 1,
         },
     )
-    seq_id: Optional[str] = field(
+    seq_id: str | None = field(
         default=None,
         metadata={
             "name": "id",
@@ -143,9 +141,8 @@ class SeqAttr:
         },
     )
 
-    @dataclass
-    class Elem:
-        pos_nrm: Optional[int] = field(
+    class Elem(BaseModel):
+        pos_nrm: int | None = field(
             default=None,
             metadata={
                 "name": "posNrm",
@@ -153,7 +150,7 @@ class SeqAttr:
                 "required": True,
             },
         )
-        elv: Optional[int] = field(
+        elv: int | None = field(
             default=None,
             metadata={
                 "type": "Element",
@@ -162,13 +159,12 @@ class SeqAttr:
         )
 
 
-@dataclass
-class Singer:
+class Singer(BaseModel):
     class Meta:
         name = "singer"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
+    pos_tick: int | None = field(
         default=0,
         metadata={
             "name": "posTick",
@@ -176,7 +172,7 @@ class Singer:
             "required": True,
         },
     )
-    v_bs: Optional[VocaloidLanguage] = field(
+    v_bs: VocaloidLanguage | None = field(
         default=VocaloidLanguage.SIMPLIFIED_CHINESE,
         metadata={
             "name": "vBS",
@@ -186,7 +182,7 @@ class Singer:
             "max_inclusive": 127,
         },
     )
-    v_pc: Optional[int] = field(
+    v_pc: int | None = field(
         default=0,
         metadata={
             "name": "vPC",
@@ -198,13 +194,12 @@ class Singer:
     )
 
 
-@dataclass
-class StylePlugin:
+class StylePlugin(BaseModel):
     class Meta:
         name = "stylePlugin"
         namespace = VSQ3_NS
 
-    style_plugin_id: Optional[str] = field(
+    style_plugin_id: str | None = field(
         default="ACA9C502-A04B-42b5-B2EB-5CEA36D16FCE",
         metadata={
             "name": "stylePluginID",
@@ -213,7 +208,7 @@ class StylePlugin:
             "length": 36,
         },
     )
-    style_plugin_name: Optional[str] = field(
+    style_plugin_name: str | None = field(
         default="VOCALOID2 Compatible Style",
         metadata={
             "name": "stylePluginName",
@@ -221,7 +216,7 @@ class StylePlugin:
             "required": True,
         },
     )
-    version: Optional[str] = field(
+    version: str | None = field(
         default="3.0.0.1",
         metadata={
             "type": "Element",
@@ -230,22 +225,19 @@ class StylePlugin:
     )
 
 
-@dataclass
-class Tempo:
+class Tempo(BaseModel):
     class Meta:
         name = "tempo"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
-        default=None,
+    pos_tick: int = field(
         metadata={
             "name": "posTick",
             "type": "Element",
             "required": True,
         },
     )
-    bpm: Optional[int] = field(
-        default=None,
+    bpm: int = field(
         metadata={
             "type": "Element",
             "required": True,
@@ -253,13 +245,12 @@ class Tempo:
     )
 
 
-@dataclass
-class TimeSig:
+class TimeSig(BaseModel):
     class Meta:
         name = "timeSig"
         namespace = VSQ3_NS
 
-    pos_mes: Optional[int] = field(
+    pos_mes: int | None = field(
         default=None,
         metadata={
             "name": "posMes",
@@ -267,14 +258,14 @@ class TimeSig:
             "required": True,
         },
     )
-    nume: Optional[int] = field(
+    nume: int | None = field(
         default=None,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    denomi: Optional[int] = field(
+    denomi: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -283,18 +274,17 @@ class TimeSig:
     )
 
 
-@dataclass
-class TypeParamAttr:
+class TypeParamAttr(BaseModel):
     class Meta:
         name = "typeParamAttr"
 
-    value: Optional[int] = field(
+    value: int | None = field(
         default=None,
         metadata={
             "required": True,
         },
     )
-    type_param_attr_id: Optional[str] = field(
+    type_param_attr_id: str | None = field(
         default=None,
         metadata={
             "name": "id",
@@ -304,8 +294,7 @@ class TypeParamAttr:
     )
 
 
-@dataclass
-class TypePhonemes:
+class TypePhonemes(BaseModel):
     class Meta:
         name = "typePhonemes"
 
@@ -315,7 +304,7 @@ class TypePhonemes:
             "required": True,
         },
     )
-    lock: Optional[int] = field(
+    lock: int | None = field(
         default=None,
         metadata={
             "type": "Attribute",
@@ -343,13 +332,12 @@ class TypeVstSdkversion(Enum):
     VALUE_3 = 3
 
 
-@dataclass
-class VVoiceParam:
+class VVoiceParam(BaseModel):
     class Meta:
         name = "vVoiceParam"
         namespace = VSQ3_NS
 
-    bre: Optional[int] = field(
+    bre: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -358,7 +346,7 @@ class VVoiceParam:
             "max_inclusive": 127,
         },
     )
-    bri: Optional[int] = field(
+    bri: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -367,7 +355,7 @@ class VVoiceParam:
             "max_inclusive": 127,
         },
     )
-    cle: Optional[int] = field(
+    cle: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -376,7 +364,7 @@ class VVoiceParam:
             "max_inclusive": 127,
         },
     )
-    gen: Optional[int] = field(
+    gen: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -385,7 +373,7 @@ class VVoiceParam:
             "max_inclusive": 127,
         },
     )
-    ope: Optional[int] = field(
+    ope: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -396,13 +384,12 @@ class VVoiceParam:
     )
 
 
-@dataclass
-class Voice:
+class Voice(BaseModel):
     class Meta:
         name = "voice"
         namespace = VSQ3_NS
 
-    pos_sec: Optional[int] = field(
+    pos_sec: int | None = field(
         default=None,
         metadata={
             "name": "posSec",
@@ -410,7 +397,7 @@ class Voice:
             "required": True,
         },
     )
-    v_bs: Optional[VocaloidLanguage] = field(
+    v_bs: VocaloidLanguage | None = field(
         default=VocaloidLanguage.SIMPLIFIED_CHINESE,
         metadata={
             "name": "vBS",
@@ -420,7 +407,7 @@ class Voice:
             "max_inclusive": 127,
         },
     )
-    v_pc: Optional[int] = field(
+    v_pc: int | None = field(
         default=0,
         metadata={
             "name": "vPC",
@@ -432,21 +419,19 @@ class Voice:
     )
 
 
-@dataclass
-class MCtrl:
+class MCtrl(BaseModel):
     class Meta:
         name = "mCtrl"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
-        default=None,
+    pos_tick: int = field(
         metadata={
             "name": "posTick",
             "type": "Element",
             "required": True,
         },
     )
-    attr: Optional[TypeParamAttr] = field(
+    attr: TypeParamAttr = field(
         default_factory=TypeParamAttr,
         metadata={
             "type": "Element",
@@ -455,13 +440,12 @@ class MCtrl:
     )
 
 
-@dataclass
-class MasterTrack:
+class MasterTrack(BaseModel):
     class Meta:
         name = "masterTrack"
         namespace = VSQ3_NS
 
-    seq_name: Optional[str] = field(
+    seq_name: str | None = field(
         default="Untitled0",
         metadata={
             "name": "seqName",
@@ -469,21 +453,21 @@ class MasterTrack:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default="New VSQ File",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    resolution: Optional[int] = field(
+    resolution: int | None = field(
         default=480,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    pre_measure: Optional[int] = field(
+    pre_measure: int = field(
         default=1,
         metadata={
             "name": "preMeasure",
@@ -510,8 +494,7 @@ class MasterTrack:
     )
 
 
-@dataclass
-class NoteStyle:
+class NoteStyle(BaseModel):
     class Meta:
         name = "noteStyle"
         namespace = VSQ3_NS
@@ -531,13 +514,12 @@ class NoteStyle:
     )
 
 
-@dataclass
-class PCtrl:
+class PCtrl(BaseModel):
     class Meta:
         name = "pCtrl"
         namespace = VSQ3_NS
 
-    pos_sec: Optional[int] = field(
+    pos_sec: int | None = field(
         default=None,
         metadata={
             "name": "posSec",
@@ -545,7 +527,7 @@ class PCtrl:
             "required": True,
         },
     )
-    attr: Optional[TypeParamAttr] = field(
+    attr: TypeParamAttr | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -554,8 +536,7 @@ class PCtrl:
     )
 
 
-@dataclass
-class PartStyle:
+class PartStyle(BaseModel):
     class Meta:
         name = "partStyle"
         namespace = VSQ3_NS
@@ -569,13 +550,12 @@ class PartStyle:
     )
 
 
-@dataclass
-class PhraseStyle:
+class PhraseStyle(BaseModel):
     class Meta:
         name = "phraseStyle"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
+    pos_tick: int | None = field(
         default=None,
         metadata={
             "name": "posTick",
@@ -592,13 +572,12 @@ class PhraseStyle:
     )
 
 
-@dataclass
-class SCtrl:
+class SCtrl(BaseModel):
     class Meta:
         name = "sCtrl"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
+    pos_tick: int | None = field(
         default=None,
         metadata={
             "name": "posTick",
@@ -606,7 +585,7 @@ class SCtrl:
             "required": True,
         },
     )
-    attr: Optional[TypeParamAttr] = field(
+    attr: TypeParamAttr | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -615,13 +594,12 @@ class SCtrl:
     )
 
 
-@dataclass
-class VVoice:
+class VVoice(BaseModel):
     class Meta:
         name = "vVoice"
         namespace = VSQ3_NS
 
-    v_bs: Optional[VocaloidLanguage] = field(
+    v_bs: VocaloidLanguage | None = field(
         default=VocaloidLanguage.SIMPLIFIED_CHINESE,
         metadata={
             "name": "vBS",
@@ -631,7 +609,7 @@ class VVoice:
             "max_inclusive": 127,
         },
     )
-    v_pc: Optional[int] = field(
+    v_pc: int | None = field(
         default=0,
         metadata={
             "name": "vPC",
@@ -641,7 +619,7 @@ class VVoice:
             "max_inclusive": 127,
         },
     )
-    comp_id: Optional[str] = field(
+    comp_id: str | None = field(
         default=None,
         metadata={
             "name": "compID",
@@ -650,7 +628,7 @@ class VVoice:
             "length": 16,
         },
     )
-    v_voice_name: Optional[str] = field(
+    v_voice_name: str | None = field(
         default=None,
         metadata={
             "name": "vVoiceName",
@@ -658,7 +636,7 @@ class VVoice:
             "required": True,
         },
     )
-    v_voice_param: Optional[VVoiceParam] = field(
+    v_voice_param: VVoiceParam | None = field(
         default_factory=VVoiceParam,
         metadata={
             "name": "vVoiceParam",
@@ -668,13 +646,12 @@ class VVoice:
     )
 
 
-@dataclass
-class VstPlugin:
+class VstPlugin(BaseModel):
     class Meta:
         name = "vstPlugin"
         namespace = VSQ3_NS
 
-    vst_plugin_id: Optional[str] = field(
+    vst_plugin_id: str | None = field(
         default=None,
         metadata={
             "name": "vstPluginID",
@@ -682,7 +659,7 @@ class VstPlugin:
             "required": True,
         },
     )
-    vst_plugin_name: Optional[str] = field(
+    vst_plugin_name: str | None = field(
         default=None,
         metadata={
             "name": "vstPluginName",
@@ -690,7 +667,7 @@ class VstPlugin:
             "required": True,
         },
     )
-    vst_sdkversion: Optional[TypeVstSdkversion] = field(
+    vst_sdkversion: TypeVstSdkversion | None = field(
         default=None,
         metadata={
             "name": "vstSDKVersion",
@@ -698,7 +675,7 @@ class VstPlugin:
             "required": True,
         },
     )
-    vst_param_num: Optional[int] = field(
+    vst_param_num: int | None = field(
         default=None,
         metadata={
             "name": "vstParamNum",
@@ -713,14 +690,14 @@ class VstPlugin:
             "type": "Element",
         },
     )
-    vst_preset_no: Optional[int] = field(
+    vst_preset_no: int | None = field(
         default=None,
         metadata={
             "name": "vstPresetNo",
             "type": "Element",
         },
     )
-    enable: Optional[int] = field(
+    enable: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -729,7 +706,7 @@ class VstPlugin:
             "max_inclusive": 1,
         },
     )
-    bypass: Optional[int] = field(
+    bypass: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -739,8 +716,7 @@ class VstPlugin:
         },
     )
 
-    @dataclass
-    class VstParamVal:
+    class VstParamVal(BaseModel):
         val: list[int] = field(
             default_factory=list,
             metadata={
@@ -749,13 +725,12 @@ class VstPlugin:
         )
 
 
-@dataclass
-class VstPluginSr:
+class VstPluginSr(BaseModel):
     class Meta:
         name = "vstPluginSR"
         namespace = VSQ3_NS
 
-    vst_plugin_id: Optional[str] = field(
+    vst_plugin_id: str | None = field(
         default=None,
         metadata={
             "name": "vstPluginID",
@@ -763,7 +738,7 @@ class VstPluginSr:
             "required": True,
         },
     )
-    vst_plugin_name: Optional[str] = field(
+    vst_plugin_name: str | None = field(
         default=None,
         metadata={
             "name": "vstPluginName",
@@ -771,7 +746,7 @@ class VstPluginSr:
             "required": True,
         },
     )
-    vst_sdkversion: Optional[TypeVstSdkversion] = field(
+    vst_sdkversion: TypeVstSdkversion | None = field(
         default=None,
         metadata={
             "name": "vstSDKVersion",
@@ -779,7 +754,7 @@ class VstPluginSr:
             "required": True,
         },
     )
-    vst_param_num: Optional[int] = field(
+    vst_param_num: int | None = field(
         default=None,
         metadata={
             "name": "vstParamNum",
@@ -794,14 +769,14 @@ class VstPluginSr:
             "type": "Element",
         },
     )
-    vst_preset_no: Optional[int] = field(
+    vst_preset_no: int | None = field(
         default=None,
         metadata={
             "name": "vstPresetNo",
             "type": "Element",
         },
     )
-    enable: Optional[int] = field(
+    enable: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -810,7 +785,7 @@ class VstPluginSr:
             "max_inclusive": 1,
         },
     )
-    bypass: Optional[int] = field(
+    bypass: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -820,8 +795,7 @@ class VstPluginSr:
         },
     )
 
-    @dataclass
-    class VstParamVal:
+    class VstParamVal(BaseModel):
         val: list[int] = field(
             default_factory=list,
             metadata={
@@ -830,13 +804,12 @@ class VstPluginSr:
         )
 
 
-@dataclass
-class WavPart:
+class WavPart(BaseModel):
     class Meta:
         name = "wavPart"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
+    pos_tick: int | None = field(
         default=None,
         metadata={
             "name": "posTick",
@@ -844,7 +817,7 @@ class WavPart:
             "required": True,
         },
     )
-    play_time: Optional[int] = field(
+    play_time: int | None = field(
         default=None,
         metadata={
             "name": "playTime",
@@ -852,7 +825,7 @@ class WavPart:
             "required": True,
         },
     )
-    part_name: Optional[str] = field(
+    part_name: str | None = field(
         default=None,
         metadata={
             "name": "partName",
@@ -860,14 +833,14 @@ class WavPart:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default=None,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    sample_rate: Optional[TypeSamplerate] = field(
+    sample_rate: TypeSamplerate | None = field(
         default=None,
         metadata={
             "name": "sampleRate",
@@ -875,7 +848,7 @@ class WavPart:
             "required": True,
         },
     )
-    sample_reso: Optional[TypeResolution] = field(
+    sample_reso: TypeResolution | None = field(
         default=None,
         metadata={
             "name": "sampleReso",
@@ -883,7 +856,7 @@ class WavPart:
             "required": True,
         },
     )
-    channels: Optional[int] = field(
+    channels: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -892,7 +865,7 @@ class WavPart:
             "max_inclusive": 2,
         },
     )
-    file_path: Optional[str] = field(
+    file_path: str | None = field(
         default=None,
         metadata={
             "name": "filePath",
@@ -902,8 +875,7 @@ class WavPart:
     )
 
 
-@dataclass
-class StereoTrack:
+class StereoTrack(BaseModel):
     class Meta:
         name = "karaokeTrack"
         namespace = VSQ3_NS
@@ -917,13 +889,12 @@ class StereoTrack:
     )
 
 
-@dataclass
-class StereoUnit:
+class StereoUnit(BaseModel):
     class Meta:
         name = "karaokeUnit"
         namespace = VSQ3_NS
 
-    in_gain: Optional[int] = field(
+    in_gain: int | None = field(
         default=0,
         metadata={
             "name": "inGain",
@@ -939,7 +910,7 @@ class StereoUnit:
             "max_occurs": 2,
         },
     )
-    mute: Optional[int] = field(
+    mute: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -948,7 +919,7 @@ class StereoUnit:
             "max_inclusive": 1,
         },
     )
-    solo: Optional[int] = field(
+    solo: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -957,7 +928,7 @@ class StereoUnit:
             "max_inclusive": 1,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -966,13 +937,12 @@ class StereoUnit:
     )
 
 
-@dataclass
-class MasterUnit:
+class MasterUnit(BaseModel):
     class Meta:
         name = "masterUnit"
         namespace = VSQ3_NS
 
-    out_dev: Optional[int] = field(
+    out_dev: int | None = field(
         default=0,
         metadata={
             "name": "outDev",
@@ -988,14 +958,14 @@ class MasterUnit:
             "max_occurs": 2,
         },
     )
-    vst_plugin_sr: Optional[VstPluginSr] = field(
+    vst_plugin_sr: VstPluginSr | None = field(
         default=None,
         metadata={
             "name": "vstPluginSR",
             "type": "Element",
         },
     )
-    ret_level: Optional[int] = field(
+    ret_level: int | None = field(
         default=0,
         metadata={
             "name": "retLevel",
@@ -1003,7 +973,7 @@ class MasterUnit:
             "required": True,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1012,29 +982,26 @@ class MasterUnit:
     )
 
 
-@dataclass
-class Note:
+class Note(BaseModel):
     class Meta:
         name = "note"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
-        default=None,
+    pos_tick: int = field(
         metadata={
             "name": "posTick",
             "type": "Element",
             "required": True,
         },
     )
-    dur_tick: Optional[int] = field(
-        default=None,
+    dur_tick: int = field(
         metadata={
             "name": "durTick",
             "type": "Element",
             "required": True,
         },
     )
-    note_num: Optional[int] = field(
+    note_num: int | None = field(
         default=None,
         metadata={
             "name": "noteNum",
@@ -1044,7 +1011,7 @@ class Note:
             "max_inclusive": 127,
         },
     )
-    velocity: Optional[int] = field(
+    velocity: int | None = field(
         default=64,
         metadata={
             "type": "Element",
@@ -1053,21 +1020,20 @@ class Note:
             "max_inclusive": 127,
         },
     )
-    lyric: Optional[str] = field(
+    lyric: str = field(
+        metadata={
+            "type": "Element",
+            "required": True,
+        },
+    )
+    phnms: TypePhonemes | None = field(
         default=None,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    phnms: Optional[TypePhonemes] = field(
-        default=None,
-        metadata={
-            "type": "Element",
-            "required": True,
-        },
-    )
-    note_style: Optional[NoteStyle] = field(
+    note_style: NoteStyle = field(
         default_factory=NoteStyle,
         metadata={
             "name": "noteStyle",
@@ -1076,13 +1042,12 @@ class Note:
     )
 
 
-@dataclass
-class ProsodyPart:
+class ProsodyPart(BaseModel):
     class Meta:
         name = "prosodyPart"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
+    pos_tick: int | None = field(
         default=None,
         metadata={
             "name": "posTick",
@@ -1090,7 +1055,7 @@ class ProsodyPart:
             "required": True,
         },
     )
-    play_time: Optional[int] = field(
+    play_time: int | None = field(
         default=None,
         metadata={
             "name": "playTime",
@@ -1098,7 +1063,7 @@ class ProsodyPart:
             "required": True,
         },
     )
-    part_name: Optional[str] = field(
+    part_name: str | None = field(
         default=None,
         metadata={
             "name": "partName",
@@ -1106,7 +1071,7 @@ class ProsodyPart:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -1149,8 +1114,7 @@ class ProsodyPart:
     )
 
 
-@dataclass
-class MonoTrack:
+class MonoTrack(BaseModel):
     class Meta:
         name = "seTrack"
         namespace = VSQ3_NS
@@ -1164,13 +1128,12 @@ class MonoTrack:
     )
 
 
-@dataclass
-class MonoUnit:
+class MonoUnit(BaseModel):
     class Meta:
         name = "seUnit"
         namespace = VSQ3_NS
 
-    in_gain: Optional[int] = field(
+    in_gain: int | None = field(
         default=0,
         metadata={
             "name": "inGain",
@@ -1186,7 +1149,7 @@ class MonoUnit:
             "max_occurs": 2,
         },
     )
-    send_level: Optional[int] = field(
+    send_level: int | None = field(
         default=-898,
         metadata={
             "name": "sendLevel",
@@ -1194,7 +1157,7 @@ class MonoUnit:
             "required": True,
         },
     )
-    send_enable: Optional[int] = field(
+    send_enable: int | None = field(
         default=0,
         metadata={
             "name": "sendEnable",
@@ -1204,7 +1167,7 @@ class MonoUnit:
             "max_inclusive": 1,
         },
     )
-    mute: Optional[int] = field(
+    mute: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1213,7 +1176,7 @@ class MonoUnit:
             "max_inclusive": 1,
         },
     )
-    solo: Optional[int] = field(
+    solo: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1222,14 +1185,14 @@ class MonoUnit:
             "max_inclusive": 1,
         },
     )
-    pan: Optional[int] = field(
+    pan: int | None = field(
         default=64,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1238,8 +1201,7 @@ class MonoUnit:
     )
 
 
-@dataclass
-class VVoiceTable:
+class VVoiceTable(BaseModel):
     class Meta:
         name = "vVoiceTable"
         namespace = VSQ3_NS
@@ -1254,13 +1216,12 @@ class VVoiceTable:
     )
 
 
-@dataclass
-class VsUnit:
+class VsUnit(BaseModel):
     class Meta:
         name = "vsUnit"
         namespace = VSQ3_NS
 
-    vs_track_no: Optional[int] = field(
+    vs_track_no: int | None = field(
         default=None,
         metadata={
             "name": "vsTrackNo",
@@ -1270,7 +1231,7 @@ class VsUnit:
             "max_inclusive": 127,
         },
     )
-    in_gain: Optional[int] = field(
+    in_gain: int | None = field(
         default=0,
         metadata={
             "name": "inGain",
@@ -1286,7 +1247,7 @@ class VsUnit:
             "max_occurs": 2,
         },
     )
-    send_level: Optional[int] = field(
+    send_level: int | None = field(
         default=-898,
         metadata={
             "name": "sendLevel",
@@ -1294,7 +1255,7 @@ class VsUnit:
             "required": True,
         },
     )
-    send_enable: Optional[int] = field(
+    send_enable: int | None = field(
         default=0,
         metadata={
             "name": "sendEnable",
@@ -1304,7 +1265,7 @@ class VsUnit:
             "max_inclusive": 1,
         },
     )
-    mute: Optional[int] = field(
+    mute: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1313,7 +1274,7 @@ class VsUnit:
             "max_inclusive": 1,
         },
     )
-    solo: Optional[int] = field(
+    solo: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1322,14 +1283,14 @@ class VsUnit:
             "max_inclusive": 1,
         },
     )
-    pan: Optional[int] = field(
+    pan: int | None = field(
         default=64,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1338,13 +1299,12 @@ class VsUnit:
     )
 
 
-@dataclass
-class Mixer:
+class Mixer(BaseModel):
     class Meta:
         name = "mixer"
         namespace = VSQ3_NS
 
-    master_unit: Optional[MasterUnit] = field(
+    master_unit: MasterUnit | None = field(
         default_factory=MasterUnit,
         metadata={
             "name": "masterUnit",
@@ -1361,7 +1321,7 @@ class Mixer:
             "max_occurs": 16,
         },
     )
-    mono_unit: Optional[MonoUnit] = field(
+    mono_unit: MonoUnit = field(
         default_factory=MonoUnit,
         metadata={
             "name": "seUnit",
@@ -1369,7 +1329,7 @@ class Mixer:
             "required": True,
         },
     )
-    stereo_unit: Optional[StereoUnit] = field(
+    stereo_unit: StereoUnit = field(
         default_factory=StereoUnit,
         metadata={
             "name": "karaokeUnit",
@@ -1379,29 +1339,26 @@ class Mixer:
     )
 
 
-@dataclass
-class MusicalPart:
+class MusicalPart(BaseModel):
     class Meta:
         name = "musicalPart"
         namespace = VSQ3_NS
 
-    pos_tick: Optional[int] = field(
-        default=None,
+    pos_tick: int = field(
         metadata={
             "name": "posTick",
             "type": "Element",
             "required": True,
         },
     )
-    play_time: Optional[int] = field(
-        default=None,
+    play_time: int = field(
         metadata={
             "name": "playTime",
             "type": "Element",
             "required": True,
         },
     )
-    part_name: Optional[str] = field(
+    part_name: str | None = field(
         default="New Part",
         metadata={
             "name": "partName",
@@ -1409,14 +1366,14 @@ class MusicalPart:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default="New Musical Part",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    style_plugin: Optional[StylePlugin] = field(
+    style_plugin: StylePlugin | None = field(
         default_factory=StylePlugin,
         metadata={
             "name": "stylePlugin",
@@ -1424,7 +1381,7 @@ class MusicalPart:
             "required": True,
         },
     )
-    part_style: Optional[PartStyle] = field(
+    part_style: PartStyle = field(
         default_factory=PartStyle,
         metadata={
             "name": "partStyle",
@@ -1467,13 +1424,12 @@ class MusicalPart:
     )
 
 
-@dataclass
-class VsTrack:
+class VsTrack(BaseModel):
     class Meta:
         name = "vsTrack"
         namespace = VSQ3_NS
 
-    vs_track_no: Optional[int] = field(
+    vs_track_no: int | None = field(
         default=None,
         metadata={
             "name": "vsTrackNo",
@@ -1483,7 +1439,7 @@ class VsTrack:
             "max_inclusive": 127,
         },
     )
-    track_name: Optional[str] = field(
+    track_name: str | None = field(
         default=None,
         metadata={
             "name": "trackName",
@@ -1491,7 +1447,7 @@ class VsTrack:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default="Track",
         metadata={
             "type": "Element",
@@ -1516,27 +1472,26 @@ class VsTrack:
     )
 
 
-@dataclass
-class Vsq3:
+class Vsq3(BaseModel):
     class Meta:
         name = "vsq3"
         namespace = VSQ3_NS
 
-    vender: Optional[str] = field(
+    vender: str | None = field(
         default="Yamaha Corporation",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    version: Optional[str] = field(
+    version: str | None = field(
         default="3.0.0.0",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    v_voice_table: Optional[VVoiceTable] = field(
+    v_voice_table: VVoiceTable = field(
         default_factory=VVoiceTable,
         metadata={
             "name": "vVoiceTable",
@@ -1544,14 +1499,14 @@ class Vsq3:
             "required": True,
         },
     )
-    mixer: Optional[Mixer] = field(
+    mixer: Mixer = field(
         default_factory=Mixer,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    master_track: Optional[MasterTrack] = field(
+    master_track: MasterTrack = field(
         default_factory=MasterTrack,
         metadata={
             "name": "masterTrack",
@@ -1568,7 +1523,7 @@ class Vsq3:
             "max_occurs": 16,
         },
     )
-    mono_track: Optional[MonoTrack] = field(
+    mono_track: MonoTrack | None = field(
         default_factory=MonoTrack,
         metadata={
             "name": "seTrack",
@@ -1576,7 +1531,7 @@ class Vsq3:
             "required": True,
         },
     )
-    stereo_track: Optional[StereoTrack] = field(
+    stereo_track: StereoTrack | None = field(
         default_factory=StereoTrack,
         metadata={
             "name": "karaokeTrack",
