@@ -1,8 +1,11 @@
-from dataclasses import dataclass, field
 from enum import Enum
 from typing import Optional
 
-from ..enums import VocaloidLanguage
+from xsdata_pydantic.fields import field
+
+from libresvip.model.base import BaseModel
+
+from .enums import VocaloidLanguage
 
 VSQ4_NS = "http://www.yamaha.co.jp/vocaloid/schema/vsq4/"
 
@@ -20,13 +23,12 @@ class ParameterNames(Enum):
     GWL = "W"
 
 
-@dataclass
-class Aux:
+class Aux(BaseModel):
     class Meta:
         name = "aux"
         namespace = VSQ4_NS
 
-    aux_id: Optional[str] = field(
+    aux_id: str | None = field(
         default=None,
         metadata={
             "name": "id",
@@ -34,7 +36,7 @@ class Aux:
             "required": True,
         },
     )
-    content: Optional[str] = field(
+    content: str | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -43,13 +45,12 @@ class Aux:
     )
 
 
-@dataclass
-class StylePlugin:
+class StylePlugin(BaseModel):
     class Meta:
         name = "sPlug"
         namespace = VSQ4_NS
 
-    style_plugin_id: Optional[str] = field(
+    style_plugin_id: str | None = field(
         default="ACA9C502-A04B-42b5-B2EB-5CEA36D16FCE",
         metadata={
             "name": "id",
@@ -58,7 +59,7 @@ class StylePlugin:
             "length": 36,
         },
     )
-    style_plugin_name: Optional[str] = field(
+    style_plugin_name: str | None = field(
         default="VOCALOID2 Compatible Style",
         metadata={
             "name": "name",
@@ -66,7 +67,7 @@ class StylePlugin:
             "required": True,
         },
     )
-    version: Optional[str] = field(
+    version: str | None = field(
         default="3.0.0.1",
         metadata={
             "type": "Element",
@@ -75,8 +76,7 @@ class StylePlugin:
     )
 
 
-@dataclass
-class SeqAttr:
+class SeqAttr(BaseModel):
     class Meta:
         name = "seq"
         namespace = VSQ4_NS
@@ -89,7 +89,7 @@ class SeqAttr:
             "min_occurs": 1,
         },
     )
-    seq_id: Optional[str] = field(
+    seq_id: str | None = field(
         default=None,
         metadata={
             "name": "id",
@@ -98,9 +98,8 @@ class SeqAttr:
         },
     )
 
-    @dataclass
-    class Elem:
-        pos_nrm: Optional[int] = field(
+    class Elem(BaseModel):
+        pos_nrm: int | None = field(
             default=None,
             metadata={
                 "name": "p",
@@ -108,7 +107,7 @@ class SeqAttr:
                 "required": True,
             },
         )
-        elv: Optional[int] = field(
+        elv: int | None = field(
             default=None,
             metadata={
                 "name": "v",
@@ -118,13 +117,12 @@ class SeqAttr:
         )
 
 
-@dataclass
-class Singer:
+class Singer(BaseModel):
     class Meta:
         name = "singer"
         namespace = VSQ4_NS
 
-    pos_tick: Optional[int] = field(
+    pos_tick: int | None = field(
         default=0,
         metadata={
             "name": "t",
@@ -132,7 +130,7 @@ class Singer:
             "required": True,
         },
     )
-    v_bs: Optional[VocaloidLanguage] = field(
+    v_bs: VocaloidLanguage | None = field(
         default=VocaloidLanguage.SIMPLIFIED_CHINESE,
         metadata={
             "name": "bs",
@@ -142,7 +140,7 @@ class Singer:
             "max_inclusive": 127,
         },
     )
-    v_pc: Optional[int] = field(
+    v_pc: int | None = field(
         default=0,
         metadata={
             "name": "pc",
@@ -154,22 +152,19 @@ class Singer:
     )
 
 
-@dataclass
-class Tempo:
+class Tempo(BaseModel):
     class Meta:
         name = "tempo"
         namespace = VSQ4_NS
 
-    pos_tick: Optional[int] = field(
-        default=None,
+    pos_tick: int = field(
         metadata={
             "name": "t",
             "type": "Element",
             "required": True,
         },
     )
-    bpm: Optional[int] = field(
-        default=None,
+    bpm: int = field(
         metadata={
             "name": "v",
             "type": "Element",
@@ -178,13 +173,12 @@ class Tempo:
     )
 
 
-@dataclass
-class TimeSig:
+class TimeSig(BaseModel):
     class Meta:
         name = "timeSig"
         namespace = VSQ4_NS
 
-    pos_mes: Optional[int] = field(
+    pos_mes: int | None = field(
         default=None,
         metadata={
             "name": "m",
@@ -192,7 +186,7 @@ class TimeSig:
             "required": True,
         },
     )
-    nume: Optional[int] = field(
+    nume: int | None = field(
         default=None,
         metadata={
             "name": "nu",
@@ -200,7 +194,7 @@ class TimeSig:
             "required": True,
         },
     )
-    denomi: Optional[int] = field(
+    denomi: int | None = field(
         default=None,
         metadata={
             "name": "de",
@@ -210,18 +204,17 @@ class TimeSig:
     )
 
 
-@dataclass
-class TypeParamAttr:
+class TypeParamAttr(BaseModel):
     class Meta:
         name = "typeParamAttr"
 
-    value: Optional[int] = field(
+    value: int | None = field(
         default=None,
         metadata={
             "required": True,
         },
     )
-    type_param_attr_id: Optional[str] = field(
+    type_param_attr_id: str | None = field(
         default=None,
         metadata={
             "name": "id",
@@ -231,8 +224,7 @@ class TypeParamAttr:
     )
 
 
-@dataclass
-class TypePhonemes:
+class TypePhonemes(BaseModel):
     class Meta:
         name = "typePhonemes"
 
@@ -242,7 +234,7 @@ class TypePhonemes:
             "required": True,
         },
     )
-    lock: Optional[int] = field(
+    lock: int | None = field(
         default=None,
         metadata={
             "type": "Attribute",
@@ -270,13 +262,12 @@ class TypeVstSdkversion(Enum):
     VALUE_3 = 3
 
 
-@dataclass
-class VVoiceParam:
+class VVoiceParam(BaseModel):
     class Meta:
         name = "vPrm"
         namespace = VSQ4_NS
 
-    bre: Optional[int] = field(
+    bre: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -285,7 +276,7 @@ class VVoiceParam:
             "max_inclusive": 127,
         },
     )
-    bri: Optional[int] = field(
+    bri: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -294,7 +285,7 @@ class VVoiceParam:
             "max_inclusive": 127,
         },
     )
-    cle: Optional[int] = field(
+    cle: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -303,7 +294,7 @@ class VVoiceParam:
             "max_inclusive": 127,
         },
     )
-    gen: Optional[int] = field(
+    gen: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -312,7 +303,7 @@ class VVoiceParam:
             "max_inclusive": 127,
         },
     )
-    ope: Optional[int] = field(
+    ope: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -323,13 +314,12 @@ class VVoiceParam:
     )
 
 
-@dataclass
-class VPrm2:
+class VPrm2(BaseModel):
     class Meta:
         name = "vPrm2"
         namespace = VSQ4_NS
 
-    bre: Optional[int] = field(
+    bre: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -338,7 +328,7 @@ class VPrm2:
             "max_inclusive": 127,
         },
     )
-    bri: Optional[int] = field(
+    bri: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -347,7 +337,7 @@ class VPrm2:
             "max_inclusive": 127,
         },
     )
-    cle: Optional[int] = field(
+    cle: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -356,7 +346,7 @@ class VPrm2:
             "max_inclusive": 127,
         },
     )
-    gen: Optional[int] = field(
+    gen: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -365,7 +355,7 @@ class VPrm2:
             "max_inclusive": 127,
         },
     )
-    ope: Optional[int] = field(
+    ope: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -374,7 +364,7 @@ class VPrm2:
             "max_inclusive": 127,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -385,21 +375,19 @@ class VPrm2:
     )
 
 
-@dataclass
-class MCtrl:
+class MCtrl(BaseModel):
     class Meta:
         name = "cc"
         namespace = VSQ4_NS
 
-    pos_tick: Optional[int] = field(
-        default=None,
+    pos_tick: int = field(
         metadata={
             "name": "t",
             "type": "Element",
             "required": True,
         },
     )
-    attr: Optional[TypeParamAttr] = field(
+    attr: TypeParamAttr = field(
         default_factory=TypeParamAttr,
         metadata={
             "name": "v",
@@ -409,13 +397,12 @@ class MCtrl:
     )
 
 
-@dataclass
-class MasterTrack:
+class MasterTrack(BaseModel):
     class Meta:
         name = "masterTrack"
         namespace = VSQ4_NS
 
-    seq_name: Optional[str] = field(
+    seq_name: str | None = field(
         default="Untitled0",
         metadata={
             "name": "seqName",
@@ -423,21 +410,21 @@ class MasterTrack:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default="New VSQ File",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    resolution: Optional[int] = field(
+    resolution: int | None = field(
         default=480,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    pre_measure: Optional[int] = field(
+    pre_measure: int = field(
         default=1,
         metadata={
             "name": "preMeasure",
@@ -464,8 +451,7 @@ class MasterTrack:
     )
 
 
-@dataclass
-class NoteStyle:
+class NoteStyle(BaseModel):
     class Meta:
         name = "nStyle"
         namespace = VSQ4_NS
@@ -486,8 +472,7 @@ class NoteStyle:
     )
 
 
-@dataclass
-class PartStyle:
+class PartStyle(BaseModel):
     class Meta:
         name = "pStyle"
         namespace = VSQ4_NS
@@ -502,13 +487,12 @@ class PartStyle:
     )
 
 
-@dataclass
-class VstPlugin:
+class VstPlugin(BaseModel):
     class Meta:
         name = "plug"
         namespace = VSQ4_NS
 
-    vst_plugin_id: Optional[str] = field(
+    vst_plugin_id: str | None = field(
         default=None,
         metadata={
             "name": "id",
@@ -516,7 +500,7 @@ class VstPlugin:
             "required": True,
         },
     )
-    vst_plugin_name: Optional[str] = field(
+    vst_plugin_name: str | None = field(
         default=None,
         metadata={
             "name": "name",
@@ -524,7 +508,7 @@ class VstPlugin:
             "required": True,
         },
     )
-    vst_sdkversion: Optional[TypeVstSdkversion] = field(
+    vst_sdkversion: TypeVstSdkversion | None = field(
         default=None,
         metadata={
             "name": "sdkVer",
@@ -532,7 +516,7 @@ class VstPlugin:
             "required": True,
         },
     )
-    vst_param_num: Optional[int] = field(
+    vst_param_num: int | None = field(
         default=None,
         metadata={
             "name": "nPrm",
@@ -547,14 +531,14 @@ class VstPlugin:
             "type": "Element",
         },
     )
-    vst_preset_no: Optional[int] = field(
+    vst_preset_no: int | None = field(
         default=None,
         metadata={
             "name": "presetNo",
             "type": "Element",
         },
     )
-    enable: Optional[int] = field(
+    enable: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -563,7 +547,7 @@ class VstPlugin:
             "max_inclusive": 1,
         },
     )
-    bypass: Optional[int] = field(
+    bypass: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -573,8 +557,7 @@ class VstPlugin:
         },
     )
 
-    @dataclass
-    class VstParamVal:
+    class VstParamVal(BaseModel):
         val: list[int] = field(
             default_factory=list,
             metadata={
@@ -584,13 +567,12 @@ class VstPlugin:
         )
 
 
-@dataclass
-class VstPluginSr:
+class VstPluginSr(BaseModel):
     class Meta:
         name = "plugSR"
         namespace = VSQ4_NS
 
-    vst_plugin_id: Optional[str] = field(
+    vst_plugin_id: str | None = field(
         default=None,
         metadata={
             "name": "id",
@@ -598,7 +580,7 @@ class VstPluginSr:
             "required": True,
         },
     )
-    vst_plugin_name: Optional[str] = field(
+    vst_plugin_name: str | None = field(
         default=None,
         metadata={
             "name": "name",
@@ -606,7 +588,7 @@ class VstPluginSr:
             "required": True,
         },
     )
-    vst_sdkversion: Optional[TypeVstSdkversion] = field(
+    vst_sdkversion: TypeVstSdkversion | None = field(
         default=None,
         metadata={
             "name": "sdkVer",
@@ -614,7 +596,7 @@ class VstPluginSr:
             "required": True,
         },
     )
-    vst_param_num: Optional[int] = field(
+    vst_param_num: int | None = field(
         default=None,
         metadata={
             "name": "nPrm",
@@ -629,14 +611,14 @@ class VstPluginSr:
             "type": "Element",
         },
     )
-    vst_preset_no: Optional[int] = field(
+    vst_preset_no: int | None = field(
         default=None,
         metadata={
             "name": "presetNo",
             "type": "Element",
         },
     )
-    enable: Optional[int] = field(
+    enable: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -645,7 +627,7 @@ class VstPluginSr:
             "max_inclusive": 1,
         },
     )
-    bypass: Optional[int] = field(
+    bypass: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -655,8 +637,7 @@ class VstPluginSr:
         },
     )
 
-    @dataclass
-    class VstParamVal:
+    class VstParamVal(BaseModel):
         val: list[int] = field(
             default_factory=list,
             metadata={
@@ -666,13 +647,12 @@ class VstPluginSr:
         )
 
 
-@dataclass
-class VVoice:
+class VVoice(BaseModel):
     class Meta:
         name = "vVoice"
         namespace = VSQ4_NS
 
-    v_bs: Optional[VocaloidLanguage] = field(
+    v_bs: VocaloidLanguage | None = field(
         default=VocaloidLanguage.SIMPLIFIED_CHINESE,
         metadata={
             "name": "bs",
@@ -682,7 +662,7 @@ class VVoice:
             "max_inclusive": 127,
         },
     )
-    v_pc: Optional[int] = field(
+    v_pc: int | None = field(
         default=0,
         metadata={
             "name": "pc",
@@ -692,7 +672,7 @@ class VVoice:
             "max_inclusive": 127,
         },
     )
-    comp_id: Optional[str] = field(
+    comp_id: str | None = field(
         default=None,
         metadata={
             "name": "id",
@@ -701,7 +681,7 @@ class VVoice:
             "length": 16,
         },
     )
-    v_voice_name: Optional[str] = field(
+    v_voice_name: str | None = field(
         default=None,
         metadata={
             "name": "name",
@@ -709,7 +689,7 @@ class VVoice:
             "required": True,
         },
     )
-    v_voice_param: Optional[VVoiceParam] = field(
+    v_voice_param: VVoiceParam | None = field(
         default_factory=VVoiceParam,
         metadata={
             "name": "vPrm",
@@ -717,14 +697,14 @@ class VVoice:
             "required": True,
         },
     )
-    id2: Optional[str] = field(
+    id2: str | None = field(
         default=None,
         metadata={
             "type": "Element",
             "length": 16,
         },
     )
-    v_prm2: Optional[VPrm2] = field(
+    v_prm2: VPrm2 | None = field(
         default=None,
         metadata={
             "name": "vPrm2",
@@ -733,13 +713,12 @@ class VVoice:
     )
 
 
-@dataclass
-class WavPart:
+class WavPart(BaseModel):
     class Meta:
         name = "wavPart"
         namespace = VSQ4_NS
 
-    pos_tick: Optional[int] = field(
+    pos_tick: int | None = field(
         default=None,
         metadata={
             "name": "t",
@@ -747,7 +726,7 @@ class WavPart:
             "required": True,
         },
     )
-    play_time: Optional[int] = field(
+    play_time: int | None = field(
         default=None,
         metadata={
             "name": "playTime",
@@ -755,7 +734,7 @@ class WavPart:
             "required": True,
         },
     )
-    part_name: Optional[str] = field(
+    part_name: str | None = field(
         default=None,
         metadata={
             "name": "name",
@@ -763,14 +742,14 @@ class WavPart:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default="New Wav Part",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    sample_rate: Optional[TypeSamplerate] = field(
+    sample_rate: TypeSamplerate | None = field(
         default=None,
         metadata={
             "name": "fs",
@@ -778,7 +757,7 @@ class WavPart:
             "required": True,
         },
     )
-    sample_reso: Optional[TypeResolution] = field(
+    sample_reso: TypeResolution | None = field(
         default=None,
         metadata={
             "name": "rs",
@@ -786,7 +765,7 @@ class WavPart:
             "required": True,
         },
     )
-    channels: Optional[int] = field(
+    channels: int | None = field(
         default=None,
         metadata={
             "name": "nCh",
@@ -796,7 +775,7 @@ class WavPart:
             "max_inclusive": 2,
         },
     )
-    file_path: Optional[str] = field(
+    file_path: str | None = field(
         default=None,
         metadata={
             "name": "filePath",
@@ -806,13 +785,12 @@ class WavPart:
     )
 
 
-@dataclass
-class MasterUnit:
+class MasterUnit(BaseModel):
     class Meta:
         name = "masterUnit"
         namespace = VSQ4_NS
 
-    out_dev: Optional[int] = field(
+    out_dev: int | None = field(
         default=0,
         metadata={
             "name": "oDev",
@@ -828,14 +806,14 @@ class MasterUnit:
             "max_occurs": 2,
         },
     )
-    vst_plugin_sr: Optional[VstPluginSr] = field(
+    vst_plugin_sr: VstPluginSr | None = field(
         default=None,
         metadata={
             "name": "plugSR",
             "type": "Element",
         },
     )
-    ret_level: Optional[int] = field(
+    ret_level: int | None = field(
         default=0,
         metadata={
             "name": "rLvl",
@@ -843,7 +821,7 @@ class MasterUnit:
             "required": True,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -852,13 +830,12 @@ class MasterUnit:
     )
 
 
-@dataclass
-class MonoTrack:
+class MonoTrack(BaseModel):
     class Meta:
         name = "monoTrack"
         namespace = VSQ4_NS
 
-    wav_part: Optional[list[WavPart]] = field(
+    wav_part: list[WavPart] = field(
         default_factory=list,
         metadata={
             "name": "wavPart",
@@ -867,13 +844,12 @@ class MonoTrack:
     )
 
 
-@dataclass
-class MonoUnit:
+class MonoUnit(BaseModel):
     class Meta:
         name = "monoUnit"
         namespace = VSQ4_NS
 
-    in_gain: Optional[int] = field(
+    in_gain: int | None = field(
         default=0,
         metadata={
             "name": "iGin",
@@ -889,7 +865,7 @@ class MonoUnit:
             "max_occurs": 2,
         },
     )
-    send_level: Optional[int] = field(
+    send_level: int | None = field(
         default=-898,
         metadata={
             "name": "sLvl",
@@ -897,7 +873,7 @@ class MonoUnit:
             "required": True,
         },
     )
-    send_enable: Optional[int] = field(
+    send_enable: int | None = field(
         default=0,
         metadata={
             "name": "sEnable",
@@ -907,7 +883,7 @@ class MonoUnit:
             "max_inclusive": 1,
         },
     )
-    mute: Optional[int] = field(
+    mute: int | None = field(
         default=0,
         metadata={
             "name": "m",
@@ -917,7 +893,7 @@ class MonoUnit:
             "max_inclusive": 1,
         },
     )
-    solo: Optional[int] = field(
+    solo: int | None = field(
         default=0,
         metadata={
             "name": "s",
@@ -927,14 +903,14 @@ class MonoUnit:
             "max_inclusive": 1,
         },
     )
-    pan: Optional[int] = field(
+    pan: int | None = field(
         default=64,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -943,29 +919,26 @@ class MonoUnit:
     )
 
 
-@dataclass
-class Note:
+class Note(BaseModel):
     class Meta:
         name = "note"
         namespace = VSQ4_NS
 
-    pos_tick: Optional[int] = field(
-        default=None,
+    pos_tick: int = field(
         metadata={
             "name": "t",
             "type": "Element",
             "required": True,
         },
     )
-    dur_tick: Optional[int] = field(
-        default=None,
+    dur_tick: int = field(
         metadata={
             "name": "dur",
             "type": "Element",
             "required": True,
         },
     )
-    note_num: Optional[int] = field(
+    note_num: int | None = field(
         default=None,
         metadata={
             "name": "n",
@@ -975,7 +948,7 @@ class Note:
             "max_inclusive": 127,
         },
     )
-    velocity: Optional[int] = field(
+    velocity: int | None = field(
         default=64,
         metadata={
             "name": "v",
@@ -985,15 +958,14 @@ class Note:
             "max_inclusive": 127,
         },
     )
-    lyric: Optional[str] = field(
-        default=None,
+    lyric: str = field(
         metadata={
             "name": "y",
             "type": "Element",
             "required": True,
         },
     )
-    phnms: Optional[TypePhonemes] = field(
+    phnms: TypePhonemes | None = field(
         default=None,
         metadata={
             "name": "p",
@@ -1001,7 +973,7 @@ class Note:
             "required": True,
         },
     )
-    note_style: Optional[NoteStyle] = field(
+    note_style: NoteStyle = field(
         default_factory=NoteStyle,
         metadata={
             "name": "nStyle",
@@ -1010,13 +982,12 @@ class Note:
     )
 
 
-@dataclass
-class StereoTrack:
+class StereoTrack(BaseModel):
     class Meta:
         name = "stTrack"
         namespace = VSQ4_NS
 
-    wav_part: Optional[list[WavPart]] = field(
+    wav_part: list[WavPart] = field(
         default_factory=list,
         metadata={
             "name": "wavPart",
@@ -1025,13 +996,12 @@ class StereoTrack:
     )
 
 
-@dataclass
-class StereoUnit:
+class StereoUnit(BaseModel):
     class Meta:
         name = "stUnit"
         namespace = VSQ4_NS
 
-    in_gain: Optional[int] = field(
+    in_gain: int | None = field(
         default=0,
         metadata={
             "name": "iGin",
@@ -1047,7 +1017,7 @@ class StereoUnit:
             "max_occurs": 2,
         },
     )
-    mute: Optional[int] = field(
+    mute: int | None = field(
         default=0,
         metadata={
             "name": "m",
@@ -1057,7 +1027,7 @@ class StereoUnit:
             "max_inclusive": 1,
         },
     )
-    solo: Optional[int] = field(
+    solo: int | None = field(
         default=0,
         metadata={
             "name": "s",
@@ -1067,7 +1037,7 @@ class StereoUnit:
             "max_inclusive": 1,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1076,8 +1046,7 @@ class StereoUnit:
     )
 
 
-@dataclass
-class VVoiceTable:
+class VVoiceTable(BaseModel):
     class Meta:
         name = "vVoiceTable"
         namespace = VSQ4_NS
@@ -1092,13 +1061,12 @@ class VVoiceTable:
     )
 
 
-@dataclass
-class VsUnit:
+class VsUnit(BaseModel):
     class Meta:
         name = "vsUnit"
         namespace = VSQ4_NS
 
-    vs_track_no: Optional[int] = field(
+    vs_track_no: int | None = field(
         default=None,
         metadata={
             "name": "tNo",
@@ -1108,7 +1076,7 @@ class VsUnit:
             "max_inclusive": 127,
         },
     )
-    in_gain: Optional[int] = field(
+    in_gain: int | None = field(
         default=0,
         metadata={
             "name": "iGin",
@@ -1124,7 +1092,7 @@ class VsUnit:
             "max_occurs": 2,
         },
     )
-    send_level: Optional[int] = field(
+    send_level: int | None = field(
         default=-898,
         metadata={
             "name": "sLvl",
@@ -1132,7 +1100,7 @@ class VsUnit:
             "required": True,
         },
     )
-    send_enable: Optional[int] = field(
+    send_enable: int | None = field(
         default=0,
         metadata={
             "name": "sEnable",
@@ -1142,7 +1110,7 @@ class VsUnit:
             "max_inclusive": 1,
         },
     )
-    mute: Optional[int] = field(
+    mute: int | None = field(
         default=0,
         metadata={
             "name": "m",
@@ -1152,7 +1120,7 @@ class VsUnit:
             "max_inclusive": 1,
         },
     )
-    solo: Optional[int] = field(
+    solo: int | None = field(
         default=0,
         metadata={
             "name": "s",
@@ -1162,14 +1130,14 @@ class VsUnit:
             "max_inclusive": 1,
         },
     )
-    pan: Optional[int] = field(
+    pan: int | None = field(
         default=64,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    vol: Optional[int] = field(
+    vol: int | None = field(
         default=0,
         metadata={
             "type": "Element",
@@ -1178,13 +1146,12 @@ class VsUnit:
     )
 
 
-@dataclass
-class Mixer:
+class Mixer(BaseModel):
     class Meta:
         name = "mixer"
         namespace = VSQ4_NS
 
-    master_unit: Optional[MasterUnit] = field(
+    master_unit: MasterUnit | None = field(
         default_factory=MasterUnit,
         metadata={
             "name": "masterUnit",
@@ -1201,7 +1168,7 @@ class Mixer:
             "max_occurs": 16,
         },
     )
-    mono_unit: Optional[MonoUnit] = field(
+    mono_unit: MonoUnit = field(
         default_factory=MonoUnit,
         metadata={
             "name": "monoUnit",
@@ -1209,7 +1176,7 @@ class Mixer:
             "required": True,
         },
     )
-    stereo_unit: Optional[StereoUnit] = field(
+    stereo_unit: StereoUnit = field(
         default_factory=StereoUnit,
         metadata={
             "name": "stUnit",
@@ -1219,29 +1186,26 @@ class Mixer:
     )
 
 
-@dataclass
-class MusicalPart:
+class MusicalPart(BaseModel):
     class Meta:
         name = "vsPart"
         namespace = VSQ4_NS
 
-    pos_tick: Optional[int] = field(
-        default=None,
+    pos_tick: int = field(
         metadata={
             "name": "t",
             "type": "Element",
             "required": True,
         },
     )
-    play_time: Optional[int] = field(
-        default=None,
+    play_time: int = field(
         metadata={
             "name": "playTime",
             "type": "Element",
             "required": True,
         },
     )
-    part_name: Optional[str] = field(
+    part_name: str | None = field(
         default="New Part",
         metadata={
             "name": "name",
@@ -1249,14 +1213,14 @@ class MusicalPart:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default="New Musical Part",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    style_plugin: Optional[StylePlugin] = field(
+    style_plugin: StylePlugin | None = field(
         default_factory=StylePlugin,
         metadata={
             "name": "sPlug",
@@ -1264,7 +1228,7 @@ class MusicalPart:
             "required": True,
         },
     )
-    part_style: Optional[PartStyle] = field(
+    part_style: PartStyle = field(
         default_factory=PartStyle,
         metadata={
             "name": "pStyle",
@@ -1291,7 +1255,7 @@ class MusicalPart:
             "type": "Element",
         },
     )
-    plane: Optional[int] = field(
+    plane: int | None = field(
         default=None,
         metadata={
             "type": "Element",
@@ -1301,13 +1265,12 @@ class MusicalPart:
     )
 
 
-@dataclass
-class VsTrack:
+class VsTrack(BaseModel):
     class Meta:
         name = "vsTrack"
         namespace = VSQ4_NS
 
-    vs_track_no: Optional[int] = field(
+    vs_track_no: int | None = field(
         default=None,
         metadata={
             "name": "tNo",
@@ -1317,7 +1280,7 @@ class VsTrack:
             "max_inclusive": 127,
         },
     )
-    track_name: Optional[str] = field(
+    track_name: str | None = field(
         default=None,
         metadata={
             "name": "name",
@@ -1325,15 +1288,15 @@ class VsTrack:
             "required": True,
         },
     )
-    comment: Optional[str] = field(
+    comment: str | None = field(
         default="Track",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    musical_part: Optional[list[MusicalPart]] = field(
-        default=None,
+    musical_part: list[MusicalPart] = field(
+        default_factory=list,
         metadata={
             "name": "vsPart",
             "type": "Element",
@@ -1341,27 +1304,26 @@ class VsTrack:
     )
 
 
-@dataclass
-class Vsq4:
+class Vsq4(BaseModel):
     class Meta:
         name = "vsq4"
         namespace = VSQ4_NS
 
-    vender: Optional[str] = field(
+    vender: str | None = field(
         default="Yamaha Corporation",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    version: Optional[str] = field(
+    version: str | None = field(
         default="4.0.0.3",
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    v_voice_table: Optional[VVoiceTable] = field(
+    v_voice_table: VVoiceTable = field(
         default_factory=VVoiceTable,
         metadata={
             "name": "vVoiceTable",
@@ -1369,14 +1331,14 @@ class Vsq4:
             "required": True,
         },
     )
-    mixer: Optional[Mixer] = field(
+    mixer: Mixer = field(
         default_factory=Mixer,
         metadata={
             "type": "Element",
             "required": True,
         },
     )
-    master_track: Optional[MasterTrack] = field(
+    master_track: MasterTrack = field(
         default_factory=MasterTrack,
         metadata={
             "name": "masterTrack",
@@ -1393,7 +1355,7 @@ class Vsq4:
             "max_occurs": 16,
         },
     )
-    mono_track: Optional[MonoTrack] = field(
+    mono_track: MonoTrack | None = field(
         default_factory=MonoTrack,
         metadata={
             "name": "monoTrack",
@@ -1401,7 +1363,7 @@ class Vsq4:
             "required": True,
         },
     )
-    stereo_track: Optional[StereoTrack] = field(
+    stereo_track: StereoTrack | None = field(
         default_factory=StereoTrack,
         metadata={
             "name": "stTrack",
